@@ -12,7 +12,7 @@ types: dict[str, str] = {
     "AWS::APS::RuleGroupsNamespace": "1898bd2e1a2fc3af",
     "AWS::APS::Scraper": "6d167939ca161a78",
     "AWS::APS::Workspace": "0739c3a13c4ccac6",
-    "AWS::ARCRegionSwitch::Plan": "f86e2a208e3b2f69",
+    "AWS::ARCRegionSwitch::Plan": "a1a2ea55c2fbda5a",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
     "AWS::AccessAnalyzer::Analyzer": "165f750ca8d78dde",
@@ -113,6 +113,7 @@ types: dict[str, str] = {
     "AWS::ApplicationSignals::Discovery": "2bbcdf020ea7fc15",
     "AWS::ApplicationSignals::GroupingConfiguration": "d6ba1088512bf212",
     "AWS::ApplicationSignals::ServiceLevelObjective": "148bbf048d668735",
+    "AWS::Athena::CapacityReservation": "cf670cf0253b02eb",
     "AWS::Athena::DataCatalog": "72b7e9ce721875ee",
     "AWS::Athena::NamedQuery": "1fd9b221f87bab5d",
     "AWS::Athena::PreparedStatement": "efe18f0108881514",
@@ -154,6 +155,7 @@ types: dict[str, str] = {
     "AWS::Bedrock::Prompt": "63cb5b7f989bfc36",
     "AWS::Bedrock::PromptVersion": "41e3e79078ba156a",
     "AWS::BedrockAgentCore::BrowserCustom": "b3f585b2b83595e9",
+    "AWS::BedrockAgentCore::BrowserProfile": "dbc879ccd777f559",
     "AWS::BedrockAgentCore::CodeInterpreterCustom": "a4789ce5aa400e99",
     "AWS::BedrockAgentCore::Gateway": "a629441d622699ce",
     "AWS::BedrockAgentCore::GatewayTarget": "a90255fe32f8754f",
@@ -169,7 +171,7 @@ types: dict[str, str] = {
     "AWS::CE::CostCategory": "02801220bf93ab09",
     "AWS::Cases::CaseRule": "3c901a066e2031a8",
     "AWS::Cases::Domain": "819687c312320180",
-    "AWS::Cases::Field": "575dad6f219c55da",
+    "AWS::Cases::Field": "bc39acc9e67530ac",
     "AWS::Cases::Layout": "f48d9c43985a0937",
     "AWS::Cases::Template": "af733164010ae401",
     "AWS::Cassandra::Keyspace": "0bd2067860b304f2",
@@ -211,14 +213,14 @@ types: dict[str, str] = {
     "AWS::CloudFront::AnycastIpList": "beb2df4a9b037d07",
     "AWS::CloudFront::CachePolicy": "53d9f632b7e1d5b7",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity": "d2e8d397beac5797",
-    "AWS::CloudFront::ConnectionFunction": "1464a5ced2e19b3a",
+    "AWS::CloudFront::ConnectionFunction": "45b04e615a243359",
     "AWS::CloudFront::ConnectionGroup": "68ca2c6e67355a40",
     "AWS::CloudFront::ContinuousDeploymentPolicy": "bf0fd1f8e692b34d",
-    "AWS::CloudFront::Distribution": "a7170a8df5323a1d",
+    "AWS::CloudFront::Distribution": "6d7cb47a3edf25ac",
     "AWS::CloudFront::DistributionTenant": "d040de3fcc228c8d",
     "AWS::CloudFront::Function": "884b82a224857dd2",
     "AWS::CloudFront::KeyGroup": "7a9f609d809f1f8e",
-    "AWS::CloudFront::KeyValueStore": "94294bdebd60f0f9",
+    "AWS::CloudFront::KeyValueStore": "3cecb676246af3f9",
     "AWS::CloudFront::MonitoringSubscription": "f9dae15a96e422a7",
     "AWS::CloudFront::OriginAccessControl": "17f386694e5709fe",
     "AWS::CloudFront::OriginRequestPolicy": "97711158d1bc4353",
@@ -226,7 +228,7 @@ types: dict[str, str] = {
     "AWS::CloudFront::RealtimeLogConfig": "94564597650a9bf8",
     "AWS::CloudFront::ResponseHeadersPolicy": "d5eaaa7cf7b104dc",
     "AWS::CloudFront::StreamingDistribution": "06c74c3c98bc5def",
-    "AWS::CloudFront::TrustStore": "1bd49a24f080ef02",
+    "AWS::CloudFront::TrustStore": "52949233848f0e48",
     "AWS::CloudFront::VpcOrigin": "eed344f918658fdd",
     "AWS::CloudTrail::Channel": "c52e6449a7514e20",
     "AWS::CloudTrail::Dashboard": "28e73ef34409d386",
@@ -234,7 +236,7 @@ types: dict[str, str] = {
     "AWS::CloudTrail::ResourcePolicy": "ab2ae9ccbbd62450",
     "AWS::CloudTrail::Trail": "7afdcfb6fa95406a",
     "AWS::CloudWatch::Alarm": "0602d31ab163094b",
-    "AWS::CloudWatch::AlarmMuteRule": "f0a042f925c1171c",
+    "AWS::CloudWatch::AlarmMuteRule": "8ae4572f5b52e53d",
     "AWS::CloudWatch::AnomalyDetector": "13b8b743191bf50f",
     "AWS::CloudWatch::CompositeAlarm": "2b2200aed34aabc4",
     "AWS::CloudWatch::Dashboard": "423086b5b02bd126",
@@ -274,6 +276,7 @@ types: dict[str, str] = {
     "AWS::Cognito::UserPoolUserToGroupAttachment": "642c498727b1c8f4",
     "AWS::Comprehend::DocumentClassifier": "db28a10be8dd6680",
     "AWS::Comprehend::Flywheel": "ca128fe279b194a4",
+    "AWS::ComputeOptimizer::AutomationRule": "6755b5f1b2a77722",
     "AWS::Config::AggregationAuthorization": "af318b77aaceeeaa",
     "AWS::Config::ConfigRule": "907ef12e35734983",
     "AWS::Config::ConfigurationAggregator": "6d45617d9786aeb6",
@@ -322,8 +325,8 @@ types: dict[str, str] = {
     "AWS::CustomerProfiles::Domain": "aa830cf9368f9f97",
     "AWS::CustomerProfiles::EventStream": "3f1d9d2ece69a5a6",
     "AWS::CustomerProfiles::EventTrigger": "433ae33b7ce88aca",
-    "AWS::CustomerProfiles::Integration": "75fad9b81132579c",
-    "AWS::CustomerProfiles::ObjectType": "8928614cac89ee07",
+    "AWS::CustomerProfiles::Integration": "927eb595a46b76ac",
+    "AWS::CustomerProfiles::ObjectType": "5cd295a870dbdc9a",
     "AWS::CustomerProfiles::SegmentDefinition": "bbf4c096c2334b52",
     "AWS::DLM::LifecyclePolicy": "bd3a2bfcc98bf552",
     "AWS::DMS::Certificate": "89efe57b4144e9ab",
@@ -392,6 +395,13 @@ types: dict[str, str] = {
     "AWS::DevOpsGuru::LogAnomalyDetectionIntegration": "c82fe28dc7521465",
     "AWS::DevOpsGuru::NotificationChannel": "2d809460f09a7b45",
     "AWS::DevOpsGuru::ResourceCollection": "d6cf75b9cf367649",
+    "AWS::DirectConnect::Connection": "816b9e564bb15a2d",
+    "AWS::DirectConnect::DirectConnectGateway": "064ba92b6e29e1bb",
+    "AWS::DirectConnect::DirectConnectGatewayAssociation": "e8b6eb4a71af1eee",
+    "AWS::DirectConnect::Lag": "5d6f47c1a9673feb",
+    "AWS::DirectConnect::PrivateVirtualInterface": "6c8c1e1388789e05",
+    "AWS::DirectConnect::PublicVirtualInterface": "ac13a4f01149c397",
+    "AWS::DirectConnect::TransitVirtualInterface": "4cbdabc6ea22d6c4",
     "AWS::DirectoryService::MicrosoftAD": "9a7cb3c87d0c07fc",
     "AWS::DirectoryService::SimpleAD": "6d2510fa67236f4b",
     "AWS::DocDB::DBCluster": "be6f39b91c56eff9",
@@ -405,7 +415,7 @@ types: dict[str, str] = {
     "AWS::DynamoDB::Table": "50e57ed2b28d4230",
     "AWS::EC2::CapacityManagerDataExport": "eadbbd5d7fd8fd3c",
     "AWS::EC2::CapacityReservation": "1ab29c6314095182",
-    "AWS::EC2::CapacityReservationFleet": "5d448b59c2d73e04",
+    "AWS::EC2::CapacityReservationFleet": "66f529dd9ae70683",
     "AWS::EC2::CarrierGateway": "ac1f397e6adda506",
     "AWS::EC2::ClientVpnAuthorizationRule": "9dfbd181c3c5a54c",
     "AWS::EC2::ClientVpnEndpoint": "d132f32844d7e05e",
@@ -413,7 +423,7 @@ types: dict[str, str] = {
     "AWS::EC2::ClientVpnTargetNetworkAssociation": "d69233d655faf0f6",
     "AWS::EC2::CustomerGateway": "4003177e29b1dfc5",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "1a8415e48effd9a9",
+    "AWS::EC2::EC2Fleet": "a6921911281e83cd",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
@@ -429,12 +439,12 @@ types: dict[str, str] = {
     "AWS::EC2::IPAMResourceDiscovery": "0a21294934d111b5",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
     "AWS::EC2::IPAMScope": "f1341090e0e57749",
-    "AWS::EC2::Instance": "7a8c89a99087d7d5",
+    "AWS::EC2::Instance": "a61701d41fad1efa",
     "AWS::EC2::InstanceConnectEndpoint": "ccb7d5f817cc9d24",
     "AWS::EC2::InternetGateway": "4c7c90cb3105c9d8",
     "AWS::EC2::IpPoolRouteTableAssociation": "071b5a1f00936f72",
     "AWS::EC2::KeyPair": "349deb28f79434e4",
-    "AWS::EC2::LaunchTemplate": "dc7d758834e70fcb",
+    "AWS::EC2::LaunchTemplate": "06d084db5ee3142a",
     "AWS::EC2::LocalGatewayRoute": "b50d8737e0b1ea90",
     "AWS::EC2::LocalGatewayRouteTable": "6892bdd3f1f99df6",
     "AWS::EC2::LocalGatewayRouteTableVPCAssociation": "b1d6ce946dcb69b8",
@@ -513,15 +523,15 @@ types: dict[str, str] = {
     "AWS::EC2::VerifiedAccessTrustProvider": "4220d49771042d48",
     "AWS::EC2::Volume": "3385669f1c48cc6c",
     "AWS::EC2::VolumeAttachment": "1f1ab62c0d6b0fdb",
-    "AWS::ECR::PullThroughCacheRule": "030a391bf2a90ed4",
+    "AWS::ECR::PullThroughCacheRule": "bab1b3208aa431ab",
     "AWS::ECR::PullTimeUpdateExclusion": "67ad05acb3cd4d21",
     "AWS::ECR::RegistryPolicy": "a36a04f4454cafc2",
     "AWS::ECR::RegistryScanningConfiguration": "68012043447b437a",
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
-    "AWS::ECR::Repository": "d569f41026af3be8",
+    "AWS::ECR::Repository": "f436b8d080c711a7",
     "AWS::ECR::RepositoryCreationTemplate": "e37496e3eb934872",
     "AWS::ECR::SigningConfiguration": "c502bcdb31b67cc1",
-    "AWS::ECS::CapacityProvider": "2fd840d01bf69b36",
+    "AWS::ECS::CapacityProvider": "75072f96ae0bbe21",
     "AWS::ECS::Cluster": "92b09b679d42fc1e",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::ExpressGatewayService": "03b7c9db813057d9",
@@ -606,9 +616,9 @@ types: dict[str, str] = {
     "AWS::Forecast::DatasetGroup": "34ee1cab025358e3",
     "AWS::GameLift::Alias": "4616734b4ebce44f",
     "AWS::GameLift::Build": "8f8a9acc7e4d2dd9",
-    "AWS::GameLift::ContainerFleet": "54b81dea6ed8eabd",
+    "AWS::GameLift::ContainerFleet": "de4ab1e1111f8c01",
     "AWS::GameLift::ContainerGroupDefinition": "0d3b10fb5f6d30c4",
-    "AWS::GameLift::Fleet": "111c22065d994414",
+    "AWS::GameLift::Fleet": "029b994d043a97ee",
     "AWS::GameLift::GameServerGroup": "f3daee5358a076d2",
     "AWS::GameLift::GameSessionQueue": "5503dfde9bf08e1d",
     "AWS::GameLift::Location": "76d3a0e2368c8d49",
@@ -668,11 +678,11 @@ types: dict[str, str] = {
     "AWS::GroundStation::MissionProfile": "32655ab91f6a315f",
     "AWS::GuardDuty::Detector": "609c5ab9768f30a4",
     "AWS::GuardDuty::Filter": "5effc026fb87131d",
-    "AWS::GuardDuty::IPSet": "82e2140b58b00302",
+    "AWS::GuardDuty::IPSet": "2755befa61203d7e",
     "AWS::GuardDuty::MalwareProtectionPlan": "d875ebc427de851e",
     "AWS::GuardDuty::Master": "5115377f51b894ca",
     "AWS::GuardDuty::Member": "4410bf4350c9fdb8",
-    "AWS::GuardDuty::PublishingDestination": "95c6a8d647a77c52",
+    "AWS::GuardDuty::PublishingDestination": "c0e7c21001df88a4",
     "AWS::GuardDuty::ThreatEntitySet": "f9e73b098cba1e1d",
     "AWS::GuardDuty::ThreatIntelSet": "41eb1d839da4d715",
     "AWS::GuardDuty::TrustedEntitySet": "150ef5b439192da2",
@@ -955,12 +965,13 @@ types: dict[str, str] = {
     "AWS::Omics::WorkflowVersion": "293e6e45ad5e99b1",
     "AWS::OpenSearchServerless::AccessPolicy": "ec7a348a493d8c4f",
     "AWS::OpenSearchServerless::Collection": "2ee2aaf7421edcad",
+    "AWS::OpenSearchServerless::CollectionGroup": "b6d93309ca936d98",
     "AWS::OpenSearchServerless::Index": "fcc40949c8a1e83a",
     "AWS::OpenSearchServerless::LifecyclePolicy": "71de0a66a6f0daa7",
     "AWS::OpenSearchServerless::SecurityConfig": "4d3e887cb7677f9c",
     "AWS::OpenSearchServerless::SecurityPolicy": "a73437e0f606fd57",
     "AWS::OpenSearchServerless::VpcEndpoint": "e4bcf34472c7a694",
-    "AWS::OpenSearchService::Application": "866ac7c65f261ec4",
+    "AWS::OpenSearchService::Application": "54acd8b539fb7b22",
     "AWS::OpenSearchService::Domain": "9066691d16aebb93",
     "AWS::OpsWorks::App": "508d500b32261320",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment": "4902f6030931194b",
@@ -980,7 +991,7 @@ types: dict[str, str] = {
     "AWS::PCAConnectorAD::Template": "ed0b568c05022bdf",
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry": "756784fc38981208",
     "AWS::PCAConnectorSCEP::Challenge": "66f2129c2055583e",
-    "AWS::PCAConnectorSCEP::Connector": "9cbd2b6a05e6eb0d",
+    "AWS::PCAConnectorSCEP::Connector": "3985d16f9d690d78",
     "AWS::Personalize::Dataset": "d0f930319da6b133",
     "AWS::Personalize::DatasetGroup": "a9925a53c157b6e3",
     "AWS::Personalize::Schema": "a82320a3520e6fc6",
@@ -1017,7 +1028,7 @@ types: dict[str, str] = {
     "AWS::QuickSight::DataSource": "407708b753626383",
     "AWS::QuickSight::Folder": "4a9e4af92dbcc718",
     "AWS::QuickSight::RefreshSchedule": "0e848e5d85a17427",
-    "AWS::QuickSight::Template": "9f99a52291094b16",
+    "AWS::QuickSight::Template": "bf2e53263bce9387",
     "AWS::QuickSight::Theme": "c85a23cc7ca1d55e",
     "AWS::QuickSight::VPCConnection": "bb1c6b99877fb6ba",
     "AWS::RAM::Permission": "978c532747f94c7b",
@@ -1152,7 +1163,7 @@ types: dict[str, str] = {
     "AWS::SQS::QueuePolicy": "8d0c3b8154e71ff3",
     "AWS::SSM::Association": "e5ce83b562338270",
     "AWS::SSM::Document": "fafd81d675e3af92",
-    "AWS::SSM::MaintenanceWindow": "54b31dcf040d1e3b",
+    "AWS::SSM::MaintenanceWindow": "8bcf8299c61efe9b",
     "AWS::SSM::MaintenanceWindowTarget": "1d59aec599d718b8",
     "AWS::SSM::MaintenanceWindowTask": "dbf020e1bce02a1c",
     "AWS::SSM::Parameter": "88998b8e50aa846a",
@@ -1185,7 +1196,7 @@ types: dict[str, str] = {
     "AWS::SageMaker::Image": "1f7b8f5745496bd2",
     "AWS::SageMaker::ImageVersion": "307ec283c9c38549",
     "AWS::SageMaker::InferenceComponent": "bf2b2e27111fb3a4",
-    "AWS::SageMaker::InferenceExperiment": "b19e56ad811b2cbd",
+    "AWS::SageMaker::InferenceExperiment": "a15f7a6adffaf10d",
     "AWS::SageMaker::MlflowTrackingServer": "82716f2317f73364",
     "AWS::SageMaker::Model": "9757bf2bdc6a25ef",
     "AWS::SageMaker::ModelBiasJobDefinition": "1357485edb491230",
@@ -1234,9 +1245,9 @@ types: dict[str, str] = {
     "AWS::ServiceCatalog::CloudFormationProduct": "662186534ff8e643",
     "AWS::ServiceCatalog::CloudFormationProvisionedProduct": "448a377417beb2e5",
     "AWS::ServiceCatalog::LaunchNotificationConstraint": "b7978856af5cccf2",
-    "AWS::ServiceCatalog::LaunchRoleConstraint": "dfc41af30527c286",
+    "AWS::ServiceCatalog::LaunchRoleConstraint": "e953e967aeda94a8",
     "AWS::ServiceCatalog::LaunchTemplateConstraint": "e457535596ed60a2",
-    "AWS::ServiceCatalog::Portfolio": "2802283288dedb80",
+    "AWS::ServiceCatalog::Portfolio": "3f12b2c638b77209",
     "AWS::ServiceCatalog::PortfolioPrincipalAssociation": "c1655e6cd9e94bc0",
     "AWS::ServiceCatalog::PortfolioProductAssociation": "39311ae1cb0b583e",
     "AWS::ServiceCatalog::PortfolioShare": "c365f2118140f92b",
