@@ -11,7 +11,7 @@ types: dict[str, str] = {
     "AWS::APS::RuleGroupsNamespace": "1898bd2e1a2fc3af",
     "AWS::APS::Scraper": "6d167939ca161a78",
     "AWS::APS::Workspace": "0739c3a13c4ccac6",
-    "AWS::ARCRegionSwitch::Plan": "f86e2a208e3b2f69",
+    "AWS::ARCRegionSwitch::Plan": "a1a2ea55c2fbda5a",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
     "AWS::AccessAnalyzer::Analyzer": "165f750ca8d78dde",
@@ -80,6 +80,7 @@ types: dict[str, str] = {
     "AWS::ApplicationSignals::Discovery": "2bbcdf020ea7fc15",
     "AWS::ApplicationSignals::GroupingConfiguration": "d6ba1088512bf212",
     "AWS::ApplicationSignals::ServiceLevelObjective": "148bbf048d668735",
+    "AWS::Athena::CapacityReservation": "cf670cf0253b02eb",
     "AWS::Athena::DataCatalog": "72b7e9ce721875ee",
     "AWS::Athena::NamedQuery": "1fd9b221f87bab5d",
     "AWS::Athena::PreparedStatement": "efe18f0108881514",
@@ -133,7 +134,7 @@ types: dict[str, str] = {
     "AWS::CloudFront::AnycastIpList": "beb2df4a9b037d07",
     "AWS::CloudFront::CachePolicy": "53d9f632b7e1d5b7",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity": "d2e8d397beac5797",
-    "AWS::CloudFront::ConnectionFunction": "1464a5ced2e19b3a",
+    "AWS::CloudFront::ConnectionFunction": "45b04e615a243359",
     "AWS::CloudFront::ConnectionGroup": "68ca2c6e67355a40",
     "AWS::CloudFront::ContinuousDeploymentPolicy": "bf0fd1f8e692b34d",
     "AWS::CloudFront::Distribution": "6d7cb47a3edf25ac",
@@ -147,14 +148,14 @@ types: dict[str, str] = {
     "AWS::CloudFront::PublicKey": "b5cac84e7e953094",
     "AWS::CloudFront::RealtimeLogConfig": "94564597650a9bf8",
     "AWS::CloudFront::ResponseHeadersPolicy": "d5eaaa7cf7b104dc",
-    "AWS::CloudFront::TrustStore": "1bd49a24f080ef02",
+    "AWS::CloudFront::TrustStore": "52949233848f0e48",
     "AWS::CloudFront::VpcOrigin": "eed344f918658fdd",
     "AWS::CloudTrail::Dashboard": "28e73ef34409d386",
     "AWS::CloudTrail::EventDataStore": "a51aca6f15d716e3",
     "AWS::CloudTrail::ResourcePolicy": "ab2ae9ccbbd62450",
     "AWS::CloudTrail::Trail": "7afdcfb6fa95406a",
     "AWS::CloudWatch::Alarm": "0602d31ab163094b",
-    "AWS::CloudWatch::AlarmMuteRule": "f0a042f925c1171c",
+    "AWS::CloudWatch::AlarmMuteRule": "8ae4572f5b52e53d",
     "AWS::CloudWatch::AnomalyDetector": "13b8b743191bf50f",
     "AWS::CloudWatch::CompositeAlarm": "2b2200aed34aabc4",
     "AWS::CloudWatch::Dashboard": "423086b5b02bd126",
@@ -218,19 +219,26 @@ types: dict[str, str] = {
     "AWS::DataSync::LocationS3": "b83bd659cd9ae32b",
     "AWS::DataSync::LocationSMB": "afc5e5a2496d1a84",
     "AWS::DataSync::Task": "ec59b72ff72a799c",
+    "AWS::DirectConnect::Connection": "816b9e564bb15a2d",
+    "AWS::DirectConnect::DirectConnectGateway": "064ba92b6e29e1bb",
+    "AWS::DirectConnect::DirectConnectGatewayAssociation": "e8b6eb4a71af1eee",
+    "AWS::DirectConnect::Lag": "5d6f47c1a9673feb",
+    "AWS::DirectConnect::PrivateVirtualInterface": "6c8c1e1388789e05",
+    "AWS::DirectConnect::PublicVirtualInterface": "ac13a4f01149c397",
+    "AWS::DirectConnect::TransitVirtualInterface": "4cbdabc6ea22d6c4",
     "AWS::DirectoryService::MicrosoftAD": "7a48b0e737a0833b",
     "AWS::DirectoryService::SimpleAD": "a87f6c61453bc19b",
     "AWS::DynamoDB::GlobalTable": "dcad01d68f1b0691",
     "AWS::DynamoDB::Table": "50e57ed2b28d4230",
     "AWS::EC2::CapacityReservation": "1ab29c6314095182",
-    "AWS::EC2::CapacityReservationFleet": "5d448b59c2d73e04",
+    "AWS::EC2::CapacityReservationFleet": "66f529dd9ae70683",
     "AWS::EC2::ClientVpnAuthorizationRule": "09dec539b3c3f428",
     "AWS::EC2::ClientVpnEndpoint": "d132f32844d7e05e",
     "AWS::EC2::ClientVpnRoute": "f1d130776f4e1473",
     "AWS::EC2::ClientVpnTargetNetworkAssociation": "d69233d655faf0f6",
     "AWS::EC2::CustomerGateway": "4003177e29b1dfc5",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "1a8415e48effd9a9",
+    "AWS::EC2::EC2Fleet": "a6921911281e83cd",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
@@ -245,12 +253,12 @@ types: dict[str, str] = {
     "AWS::EC2::IPAMResourceDiscovery": "0a21294934d111b5",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
     "AWS::EC2::IPAMScope": "f1341090e0e57749",
-    "AWS::EC2::Instance": "7a8c89a99087d7d5",
+    "AWS::EC2::Instance": "a61701d41fad1efa",
     "AWS::EC2::InstanceConnectEndpoint": "ccb7d5f817cc9d24",
     "AWS::EC2::InternetGateway": "4c7c90cb3105c9d8",
     "AWS::EC2::IpPoolRouteTableAssociation": "071b5a1f00936f72",
     "AWS::EC2::KeyPair": "349deb28f79434e4",
-    "AWS::EC2::LaunchTemplate": "dc7d758834e70fcb",
+    "AWS::EC2::LaunchTemplate": "06d084db5ee3142a",
     "AWS::EC2::NatGateway": "28e80cb1fcf92145",
     "AWS::EC2::NetworkAcl": "41c7ec1cea436cd8",
     "AWS::EC2::NetworkAclEntry": "d4fc9ce8669023f0",
@@ -320,14 +328,14 @@ types: dict[str, str] = {
     "AWS::EC2::VPNGatewayRoutePropagation": "5e03d41fa9dc15b9",
     "AWS::EC2::Volume": "3385669f1c48cc6c",
     "AWS::EC2::VolumeAttachment": "1f1ab62c0d6b0fdb",
-    "AWS::ECR::PullThroughCacheRule": "030a391bf2a90ed4",
+    "AWS::ECR::PullThroughCacheRule": "bab1b3208aa431ab",
     "AWS::ECR::PullTimeUpdateExclusion": "67ad05acb3cd4d21",
     "AWS::ECR::RegistryPolicy": "a36a04f4454cafc2",
     "AWS::ECR::RegistryScanningConfiguration": "68012043447b437a",
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
-    "AWS::ECR::Repository": "d569f41026af3be8",
+    "AWS::ECR::Repository": "f436b8d080c711a7",
     "AWS::ECR::RepositoryCreationTemplate": "e37496e3eb934872",
-    "AWS::ECS::CapacityProvider": "2fd840d01bf69b36",
+    "AWS::ECS::CapacityProvider": "75072f96ae0bbe21",
     "AWS::ECS::Cluster": "92b09b679d42fc1e",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::ExpressGatewayService": "03b7c9db813057d9",
@@ -418,11 +426,11 @@ types: dict[str, str] = {
     "AWS::Glue::Workflow": "7889f86fa2b1958f",
     "AWS::GuardDuty::Detector": "609c5ab9768f30a4",
     "AWS::GuardDuty::Filter": "5effc026fb87131d",
-    "AWS::GuardDuty::IPSet": "82e2140b58b00302",
+    "AWS::GuardDuty::IPSet": "2755befa61203d7e",
     "AWS::GuardDuty::MalwareProtectionPlan": "d875ebc427de851e",
     "AWS::GuardDuty::Master": "5115377f51b894ca",
     "AWS::GuardDuty::Member": "4410bf4350c9fdb8",
-    "AWS::GuardDuty::PublishingDestination": "95c6a8d647a77c52",
+    "AWS::GuardDuty::PublishingDestination": "c0e7c21001df88a4",
     "AWS::GuardDuty::ThreatEntitySet": "f9e73b098cba1e1d",
     "AWS::GuardDuty::ThreatIntelSet": "41eb1d839da4d715",
     "AWS::GuardDuty::TrustedEntitySet": "150ef5b439192da2",
@@ -567,7 +575,7 @@ types: dict[str, str] = {
     "AWS::NetworkManager::VpcAttachment": "a06da0d509ded081",
     "AWS::Oam::Link": "4d4e114e0f615d82",
     "AWS::Oam::Sink": "81957ea027e4c201",
-    "AWS::OpenSearchService::Domain": "1c09878d526db02c",
+    "AWS::OpenSearchService::Domain": "9066691d16aebb93",
     "AWS::OpsWorks::App": "508d500b32261320",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment": "4902f6030931194b",
     "AWS::OpsWorks::Instance": "cd0b1a2973e2b977",
@@ -586,7 +594,7 @@ types: dict[str, str] = {
     "AWS::PCAConnectorAD::Template": "ed0b568c05022bdf",
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry": "756784fc38981208",
     "AWS::PCAConnectorSCEP::Challenge": "66f2129c2055583e",
-    "AWS::PCAConnectorSCEP::Connector": "9cbd2b6a05e6eb0d",
+    "AWS::PCAConnectorSCEP::Connector": "3985d16f9d690d78",
     "AWS::RAM::Permission": "978c532747f94c7b",
     "AWS::RAM::ResourceShare": "b4b5ff31bc5f95b0",
     "AWS::RDS::DBCluster": "9c7540d3d4699497",
@@ -676,7 +684,7 @@ types: dict[str, str] = {
     "AWS::SQS::QueuePolicy": "8d0c3b8154e71ff3",
     "AWS::SSM::Association": "e5ce83b562338270",
     "AWS::SSM::Document": "fafd81d675e3af92",
-    "AWS::SSM::MaintenanceWindow": "54b31dcf040d1e3b",
+    "AWS::SSM::MaintenanceWindow": "8bcf8299c61efe9b",
     "AWS::SSM::MaintenanceWindowTarget": "1d59aec599d718b8",
     "AWS::SSM::MaintenanceWindowTask": "dbf020e1bce02a1c",
     "AWS::SSM::Parameter": "88998b8e50aa846a",
@@ -691,6 +699,7 @@ types: dict[str, str] = {
     "AWS::SageMaker::Cluster": "439ccbf60a68017e",
     "AWS::SageMaker::MlflowTrackingServer": "82716f2317f73364",
     "AWS::SageMaker::ModelCard": "89534938581c1015",
+    "AWS::SageMaker::Pipeline": "d0698ac81fb18f57",
     "AWS::SageMaker::ProcessingJob": "e1994976600f5bae",
     "AWS::Scheduler::Schedule": "e8b60514af25a837",
     "AWS::Scheduler::ScheduleGroup": "ef710d09dbb243bf",
@@ -713,9 +722,9 @@ types: dict[str, str] = {
     "AWS::ServiceCatalog::CloudFormationProduct": "662186534ff8e643",
     "AWS::ServiceCatalog::CloudFormationProvisionedProduct": "448a377417beb2e5",
     "AWS::ServiceCatalog::LaunchNotificationConstraint": "b7978856af5cccf2",
-    "AWS::ServiceCatalog::LaunchRoleConstraint": "dfc41af30527c286",
+    "AWS::ServiceCatalog::LaunchRoleConstraint": "e953e967aeda94a8",
     "AWS::ServiceCatalog::LaunchTemplateConstraint": "e457535596ed60a2",
-    "AWS::ServiceCatalog::Portfolio": "52a609bb3d2294b5",
+    "AWS::ServiceCatalog::Portfolio": "4a1c306059a85c39",
     "AWS::ServiceCatalog::PortfolioPrincipalAssociation": "c1655e6cd9e94bc0",
     "AWS::ServiceCatalog::PortfolioProductAssociation": "39311ae1cb0b583e",
     "AWS::ServiceCatalog::PortfolioShare": "c365f2118140f92b",
