@@ -6,7 +6,7 @@ types: dict[str, str] = {
     "AWS::ACMPCA::CertificateAuthority": "aaf234b2120b5659",
     "AWS::ACMPCA::CertificateAuthorityActivation": "a62fb980b49a2961",
     "AWS::ACMPCA::Permission": "04b877e245730b3e",
-    "AWS::ARCRegionSwitch::Plan": "f86e2a208e3b2f69",
+    "AWS::ARCRegionSwitch::Plan": "a1a2ea55c2fbda5a",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
     "AWS::AccessAnalyzer::Analyzer": "165f750ca8d78dde",
@@ -100,7 +100,7 @@ types: dict[str, str] = {
     "AWS::CloudFront::TrustStore": "1bd49a24f080ef02",
     "AWS::CloudTrail::Trail": "7afdcfb6fa95406a",
     "AWS::CloudWatch::Alarm": "0602d31ab163094b",
-    "AWS::CloudWatch::AlarmMuteRule": "f0a042f925c1171c",
+    "AWS::CloudWatch::AlarmMuteRule": "8ae4572f5b52e53d",
     "AWS::CloudWatch::AnomalyDetector": "13b8b743191bf50f",
     "AWS::CloudWatch::CompositeAlarm": "2b2200aed34aabc4",
     "AWS::CloudWatch::Dashboard": "423086b5b02bd126",
@@ -114,6 +114,16 @@ types: dict[str, str] = {
     "AWS::CodeDeploy::DeploymentGroup": "87161f201431211b",
     "AWS::CodePipeline::CustomActionType": "b19c98d474c1c3e6",
     "AWS::CodePipeline::Pipeline": "dfdaf176e25c03e7",
+    "AWS::Cognito::IdentityPool": "3df22057c8e2ef54",
+    "AWS::Cognito::IdentityPoolPrincipalTag": "3ae793569104c4f6",
+    "AWS::Cognito::IdentityPoolRoleAttachment": "2a5296f4ca5a2ff7",
+    "AWS::Cognito::LogDeliveryConfiguration": "2e1fa665bc591a0b",
+    "AWS::Cognito::UserPool": "615b9da8e393791f",
+    "AWS::Cognito::UserPoolClient": "fe665a1921d29144",
+    "AWS::Cognito::UserPoolGroup": "a7315a389c858da9",
+    "AWS::Cognito::UserPoolRiskConfigurationAttachment": "650fce2645198ef2",
+    "AWS::Cognito::UserPoolUser": "61780cf8beb842dc",
+    "AWS::Cognito::UserPoolUserToGroupAttachment": "642c498727b1c8f4",
     "AWS::Config::AggregationAuthorization": "af318b77aaceeeaa",
     "AWS::Config::ConfigRule": "907ef12e35734983",
     "AWS::Config::ConfigurationAggregator": "6d45617d9786aeb6",
@@ -141,15 +151,22 @@ types: dict[str, str] = {
     "AWS::DataSync::LocationS3": "b83bd659cd9ae32b",
     "AWS::DataSync::LocationSMB": "afc5e5a2496d1a84",
     "AWS::DataSync::Task": "ec59b72ff72a799c",
+    "AWS::DirectConnect::Connection": "816b9e564bb15a2d",
+    "AWS::DirectConnect::DirectConnectGateway": "064ba92b6e29e1bb",
+    "AWS::DirectConnect::DirectConnectGatewayAssociation": "e8b6eb4a71af1eee",
+    "AWS::DirectConnect::Lag": "5d6f47c1a9673feb",
+    "AWS::DirectConnect::PrivateVirtualInterface": "6c8c1e1388789e05",
+    "AWS::DirectConnect::PublicVirtualInterface": "ac13a4f01149c397",
+    "AWS::DirectConnect::TransitVirtualInterface": "4cbdabc6ea22d6c4",
     "AWS::DirectoryService::MicrosoftAD": "7a48b0e737a0833b",
     "AWS::DirectoryService::SimpleAD": "a87f6c61453bc19b",
     "AWS::DynamoDB::GlobalTable": "dcad01d68f1b0691",
     "AWS::DynamoDB::Table": "50e57ed2b28d4230",
     "AWS::EC2::CapacityReservation": "1ab29c6314095182",
-    "AWS::EC2::CapacityReservationFleet": "5d448b59c2d73e04",
+    "AWS::EC2::CapacityReservationFleet": "66f529dd9ae70683",
     "AWS::EC2::CustomerGateway": "4003177e29b1dfc5",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "1a8415e48effd9a9",
+    "AWS::EC2::EC2Fleet": "a6921911281e83cd",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
@@ -164,11 +181,11 @@ types: dict[str, str] = {
     "AWS::EC2::IPAMResourceDiscovery": "0a21294934d111b5",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
     "AWS::EC2::IPAMScope": "f1341090e0e57749",
-    "AWS::EC2::Instance": "7a8c89a99087d7d5",
+    "AWS::EC2::Instance": "a61701d41fad1efa",
     "AWS::EC2::InstanceConnectEndpoint": "ccb7d5f817cc9d24",
     "AWS::EC2::InternetGateway": "4c7c90cb3105c9d8",
     "AWS::EC2::KeyPair": "349deb28f79434e4",
-    "AWS::EC2::LaunchTemplate": "dc7d758834e70fcb",
+    "AWS::EC2::LaunchTemplate": "06d084db5ee3142a",
     "AWS::EC2::NatGateway": "28e80cb1fcf92145",
     "AWS::EC2::NetworkAcl": "41c7ec1cea436cd8",
     "AWS::EC2::NetworkAclEntry": "d4fc9ce8669023f0",
@@ -229,20 +246,20 @@ types: dict[str, str] = {
     "AWS::EC2::VPCGatewayAttachment": "1dc77043848e8e94",
     "AWS::EC2::VPCPeeringConnection": "41b9860245304058",
     "AWS::EC2::VPNConcentrator": "78aca3962b6da301",
-    "AWS::EC2::VPNConnection": "3bf3a2c97e027241",
+    "AWS::EC2::VPNConnection": "64de71e4f82fffe6",
     "AWS::EC2::VPNConnectionRoute": "00194e67a2d7f53d",
     "AWS::EC2::VPNGateway": "1e2f029e99547e1a",
     "AWS::EC2::VPNGatewayRoutePropagation": "5e03d41fa9dc15b9",
     "AWS::EC2::Volume": "3385669f1c48cc6c",
     "AWS::EC2::VolumeAttachment": "1f1ab62c0d6b0fdb",
-    "AWS::ECR::PullThroughCacheRule": "030a391bf2a90ed4",
+    "AWS::ECR::PullThroughCacheRule": "bab1b3208aa431ab",
     "AWS::ECR::PullTimeUpdateExclusion": "67ad05acb3cd4d21",
     "AWS::ECR::RegistryPolicy": "a36a04f4454cafc2",
     "AWS::ECR::RegistryScanningConfiguration": "68012043447b437a",
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
-    "AWS::ECR::Repository": "d569f41026af3be8",
+    "AWS::ECR::Repository": "f436b8d080c711a7",
     "AWS::ECR::RepositoryCreationTemplate": "e37496e3eb934872",
-    "AWS::ECS::CapacityProvider": "2fd840d01bf69b36",
+    "AWS::ECS::CapacityProvider": "75072f96ae0bbe21",
     "AWS::ECS::Cluster": "92b09b679d42fc1e",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::ExpressGatewayService": "03b7c9db813057d9",
@@ -312,11 +329,11 @@ types: dict[str, str] = {
     "AWS::Glue::Workflow": "7889f86fa2b1958f",
     "AWS::GuardDuty::Detector": "609c5ab9768f30a4",
     "AWS::GuardDuty::Filter": "5effc026fb87131d",
-    "AWS::GuardDuty::IPSet": "82e2140b58b00302",
+    "AWS::GuardDuty::IPSet": "2755befa61203d7e",
     "AWS::GuardDuty::MalwareProtectionPlan": "d875ebc427de851e",
     "AWS::GuardDuty::Master": "5115377f51b894ca",
     "AWS::GuardDuty::Member": "4410bf4350c9fdb8",
-    "AWS::GuardDuty::PublishingDestination": "95c6a8d647a77c52",
+    "AWS::GuardDuty::PublishingDestination": "c0e7c21001df88a4",
     "AWS::GuardDuty::ThreatEntitySet": "f9e73b098cba1e1d",
     "AWS::GuardDuty::ThreatIntelSet": "41eb1d839da4d715",
     "AWS::GuardDuty::TrustedEntitySet": "150ef5b439192da2",
@@ -418,7 +435,7 @@ types: dict[str, str] = {
     "AWS::NetworkManager::VpcAttachment": "a06da0d509ded081",
     "AWS::Oam::Link": "4d4e114e0f615d82",
     "AWS::Oam::Sink": "81957ea027e4c201",
-    "AWS::OpenSearchService::Domain": "1c09878d526db02c",
+    "AWS::OpenSearchService::Domain": "9066691d16aebb93",
     "AWS::OpsWorks::App": "508d500b32261320",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment": "4902f6030931194b",
     "AWS::OpsWorks::Instance": "cd0b1a2973e2b977",
@@ -506,7 +523,7 @@ types: dict[str, str] = {
     "AWS::SQS::QueuePolicy": "8d0c3b8154e71ff3",
     "AWS::SSM::Association": "e5ce83b562338270",
     "AWS::SSM::Document": "fafd81d675e3af92",
-    "AWS::SSM::MaintenanceWindow": "54b31dcf040d1e3b",
+    "AWS::SSM::MaintenanceWindow": "8bcf8299c61efe9b",
     "AWS::SSM::MaintenanceWindowTarget": "1d59aec599d718b8",
     "AWS::SSM::MaintenanceWindowTask": "dbf020e1bce02a1c",
     "AWS::SSM::Parameter": "88998b8e50aa846a",
