@@ -11,7 +11,7 @@ types: dict[str, str] = {
     "AWS::APS::RuleGroupsNamespace": "1898bd2e1a2fc3af",
     "AWS::APS::Scraper": "6d167939ca161a78",
     "AWS::APS::Workspace": "0739c3a13c4ccac6",
-    "AWS::ARCRegionSwitch::Plan": "f86e2a208e3b2f69",
+    "AWS::ARCRegionSwitch::Plan": "a1a2ea55c2fbda5a",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
     "AWS::AccessAnalyzer::Analyzer": "165f750ca8d78dde",
@@ -112,6 +112,7 @@ types: dict[str, str] = {
     "AWS::ApplicationSignals::Discovery": "2bbcdf020ea7fc15",
     "AWS::ApplicationSignals::GroupingConfiguration": "d6ba1088512bf212",
     "AWS::ApplicationSignals::ServiceLevelObjective": "148bbf048d668735",
+    "AWS::Athena::CapacityReservation": "cf670cf0253b02eb",
     "AWS::Athena::DataCatalog": "72b7e9ce721875ee",
     "AWS::Athena::NamedQuery": "1fd9b221f87bab5d",
     "AWS::Athena::PreparedStatement": "efe18f0108881514",
@@ -224,7 +225,7 @@ types: dict[str, str] = {
     "AWS::CloudTrail::ResourcePolicy": "ab2ae9ccbbd62450",
     "AWS::CloudTrail::Trail": "7afdcfb6fa95406a",
     "AWS::CloudWatch::Alarm": "0602d31ab163094b",
-    "AWS::CloudWatch::AlarmMuteRule": "f0a042f925c1171c",
+    "AWS::CloudWatch::AlarmMuteRule": "8ae4572f5b52e53d",
     "AWS::CloudWatch::AnomalyDetector": "13b8b743191bf50f",
     "AWS::CloudWatch::CompositeAlarm": "2b2200aed34aabc4",
     "AWS::CloudWatch::Dashboard": "423086b5b02bd126",
@@ -264,6 +265,7 @@ types: dict[str, str] = {
     "AWS::Cognito::UserPoolUserToGroupAttachment": "642c498727b1c8f4",
     "AWS::Comprehend::DocumentClassifier": "db28a10be8dd6680",
     "AWS::Comprehend::Flywheel": "ca128fe279b194a4",
+    "AWS::ComputeOptimizer::AutomationRule": "6755b5f1b2a77722",
     "AWS::Config::AggregationAuthorization": "af318b77aaceeeaa",
     "AWS::Config::ConfigRule": "907ef12e35734983",
     "AWS::Config::ConfigurationAggregator": "6d45617d9786aeb6",
@@ -314,8 +316,8 @@ types: dict[str, str] = {
     "AWS::CustomerProfiles::Domain": "aa830cf9368f9f97",
     "AWS::CustomerProfiles::EventStream": "3f1d9d2ece69a5a6",
     "AWS::CustomerProfiles::EventTrigger": "433ae33b7ce88aca",
-    "AWS::CustomerProfiles::Integration": "75fad9b81132579c",
-    "AWS::CustomerProfiles::ObjectType": "8928614cac89ee07",
+    "AWS::CustomerProfiles::Integration": "927eb595a46b76ac",
+    "AWS::CustomerProfiles::ObjectType": "5cd295a870dbdc9a",
     "AWS::CustomerProfiles::SegmentDefinition": "bbf4c096c2334b52",
     "AWS::DLM::LifecyclePolicy": "bd3a2bfcc98bf552",
     "AWS::DMS::Certificate": "89efe57b4144e9ab",
@@ -337,19 +339,19 @@ types: dict[str, str] = {
     "AWS::DataBrew::Ruleset": "7a2cecd2daaf227e",
     "AWS::DataBrew::Schedule": "81971b6c3ceef52e",
     "AWS::DataPipeline::Pipeline": "0200bdbc5529afe3",
-    "AWS::DataSync::Agent": "68e0425ca31a7844",
-    "AWS::DataSync::LocationAzureBlob": "f0cbf095b3395f82",
-    "AWS::DataSync::LocationEFS": "643fd37b6ed5e6ed",
-    "AWS::DataSync::LocationFSxLustre": "5ac58e3617a3ec37",
-    "AWS::DataSync::LocationFSxONTAP": "c19db5ee97b37180",
-    "AWS::DataSync::LocationFSxOpenZFS": "6a9de3c6ec56ba85",
-    "AWS::DataSync::LocationFSxWindows": "958c329833002c7c",
-    "AWS::DataSync::LocationHDFS": "d1676e346c66185f",
-    "AWS::DataSync::LocationNFS": "b4b1757a410e5e50",
-    "AWS::DataSync::LocationObjectStorage": "a9c25b397b587b62",
-    "AWS::DataSync::LocationS3": "b83bd659cd9ae32b",
-    "AWS::DataSync::LocationSMB": "afc5e5a2496d1a84",
-    "AWS::DataSync::Task": "ec59b72ff72a799c",
+    "AWS::DataSync::Agent": "d3a5fe3ab751b18f",
+    "AWS::DataSync::LocationAzureBlob": "6d28fbfcade96028",
+    "AWS::DataSync::LocationEFS": "88ace952f3e3b739",
+    "AWS::DataSync::LocationFSxLustre": "38fcf6001961bbfc",
+    "AWS::DataSync::LocationFSxONTAP": "96d1db06d880393a",
+    "AWS::DataSync::LocationFSxOpenZFS": "061aaa5580b7b707",
+    "AWS::DataSync::LocationFSxWindows": "ecd5ee7072bae03b",
+    "AWS::DataSync::LocationHDFS": "b00a0b0ac7f91aba",
+    "AWS::DataSync::LocationNFS": "fd57f33b0f494c27",
+    "AWS::DataSync::LocationObjectStorage": "a5012c826a08f3e8",
+    "AWS::DataSync::LocationS3": "d9f087e59be69eec",
+    "AWS::DataSync::LocationSMB": "01bbd3daa55f2a4c",
+    "AWS::DataSync::Task": "983b864808e1db63",
     "AWS::DataZone::Connection": "4c5bd872b555a360",
     "AWS::DataZone::DataSource": "64d1b57899d8e4bf",
     "AWS::DataZone::Domain": "a73fade42476d81b",
@@ -373,6 +375,13 @@ types: dict[str, str] = {
     "AWS::DevOpsGuru::LogAnomalyDetectionIntegration": "c82fe28dc7521465",
     "AWS::DevOpsGuru::NotificationChannel": "2d809460f09a7b45",
     "AWS::DevOpsGuru::ResourceCollection": "d6cf75b9cf367649",
+    "AWS::DirectConnect::Connection": "816b9e564bb15a2d",
+    "AWS::DirectConnect::DirectConnectGateway": "064ba92b6e29e1bb",
+    "AWS::DirectConnect::DirectConnectGatewayAssociation": "e8b6eb4a71af1eee",
+    "AWS::DirectConnect::Lag": "5d6f47c1a9673feb",
+    "AWS::DirectConnect::PrivateVirtualInterface": "6c8c1e1388789e05",
+    "AWS::DirectConnect::PublicVirtualInterface": "ac13a4f01149c397",
+    "AWS::DirectConnect::TransitVirtualInterface": "4cbdabc6ea22d6c4",
     "AWS::DirectoryService::MicrosoftAD": "9a7cb3c87d0c07fc",
     "AWS::DirectoryService::SimpleAD": "6d2510fa67236f4b",
     "AWS::DocDB::DBCluster": "be6f39b91c56eff9",
@@ -380,13 +389,13 @@ types: dict[str, str] = {
     "AWS::DocDB::DBInstance": "253562f270b587ac",
     "AWS::DocDB::DBSubnetGroup": "ccb97a9452b2284d",
     "AWS::DocDB::EventSubscription": "d22815028d03f301",
-    "AWS::DocDB::GlobalCluster": "8a43a2ee7a595e9a",
+    "AWS::DocDB::GlobalCluster": "6cbd1fec2debea5e",
     "AWS::DocDBElastic::Cluster": "28672c1fbb8ef381",
     "AWS::DynamoDB::GlobalTable": "dcad01d68f1b0691",
     "AWS::DynamoDB::Table": "50e57ed2b28d4230",
     "AWS::EC2::CapacityManagerDataExport": "eadbbd5d7fd8fd3c",
     "AWS::EC2::CapacityReservation": "1ab29c6314095182",
-    "AWS::EC2::CapacityReservationFleet": "5d448b59c2d73e04",
+    "AWS::EC2::CapacityReservationFleet": "66f529dd9ae70683",
     "AWS::EC2::CarrierGateway": "ac1f397e6adda506",
     "AWS::EC2::ClientVpnAuthorizationRule": "9dfbd181c3c5a54c",
     "AWS::EC2::ClientVpnEndpoint": "d132f32844d7e05e",
@@ -394,7 +403,7 @@ types: dict[str, str] = {
     "AWS::EC2::ClientVpnTargetNetworkAssociation": "d69233d655faf0f6",
     "AWS::EC2::CustomerGateway": "4003177e29b1dfc5",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "1a8415e48effd9a9",
+    "AWS::EC2::EC2Fleet": "a6921911281e83cd",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
@@ -410,12 +419,12 @@ types: dict[str, str] = {
     "AWS::EC2::IPAMResourceDiscovery": "0a21294934d111b5",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
     "AWS::EC2::IPAMScope": "f1341090e0e57749",
-    "AWS::EC2::Instance": "7a8c89a99087d7d5",
+    "AWS::EC2::Instance": "a61701d41fad1efa",
     "AWS::EC2::InstanceConnectEndpoint": "ccb7d5f817cc9d24",
     "AWS::EC2::InternetGateway": "4c7c90cb3105c9d8",
     "AWS::EC2::IpPoolRouteTableAssociation": "071b5a1f00936f72",
     "AWS::EC2::KeyPair": "349deb28f79434e4",
-    "AWS::EC2::LaunchTemplate": "51d9c721a02159c3",
+    "AWS::EC2::LaunchTemplate": "dbb4de05d9ee7263",
     "AWS::EC2::LocalGatewayRoute": "b50d8737e0b1ea90",
     "AWS::EC2::LocalGatewayRouteTable": "6892bdd3f1f99df6",
     "AWS::EC2::LocalGatewayRouteTableVPCAssociation": "b1d6ce946dcb69b8",
@@ -485,7 +494,7 @@ types: dict[str, str] = {
     "AWS::EC2::VPCGatewayAttachment": "1dc77043848e8e94",
     "AWS::EC2::VPCPeeringConnection": "41b9860245304058",
     "AWS::EC2::VPNConcentrator": "78aca3962b6da301",
-    "AWS::EC2::VPNConnection": "3bf3a2c97e027241",
+    "AWS::EC2::VPNConnection": "64de71e4f82fffe6",
     "AWS::EC2::VPNConnectionRoute": "00194e67a2d7f53d",
     "AWS::EC2::VPNGateway": "1e2f029e99547e1a",
     "AWS::EC2::VPNGatewayRoutePropagation": "5e03d41fa9dc15b9",
@@ -495,15 +504,15 @@ types: dict[str, str] = {
     "AWS::EC2::VerifiedAccessTrustProvider": "4220d49771042d48",
     "AWS::EC2::Volume": "3385669f1c48cc6c",
     "AWS::EC2::VolumeAttachment": "1f1ab62c0d6b0fdb",
-    "AWS::ECR::PullThroughCacheRule": "030a391bf2a90ed4",
+    "AWS::ECR::PullThroughCacheRule": "bab1b3208aa431ab",
     "AWS::ECR::PullTimeUpdateExclusion": "67ad05acb3cd4d21",
     "AWS::ECR::RegistryPolicy": "a36a04f4454cafc2",
     "AWS::ECR::RegistryScanningConfiguration": "68012043447b437a",
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
-    "AWS::ECR::Repository": "d569f41026af3be8",
+    "AWS::ECR::Repository": "f436b8d080c711a7",
     "AWS::ECR::RepositoryCreationTemplate": "e37496e3eb934872",
     "AWS::ECR::SigningConfiguration": "c502bcdb31b67cc1",
-    "AWS::ECS::CapacityProvider": "2fd840d01bf69b36",
+    "AWS::ECS::CapacityProvider": "75072f96ae0bbe21",
     "AWS::ECS::Cluster": "92b09b679d42fc1e",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::ExpressGatewayService": "03b7c9db813057d9",
@@ -538,7 +547,7 @@ types: dict[str, str] = {
     "AWS::ElastiCache::CacheCluster": "1220b6bbd633ae68",
     "AWS::ElastiCache::GlobalReplicationGroup": "2af3062bf5b2cf7f",
     "AWS::ElastiCache::ParameterGroup": "b0e1dec3cd05f739",
-    "AWS::ElastiCache::ReplicationGroup": "0b94d00dcdccdba6",
+    "AWS::ElastiCache::ReplicationGroup": "a7cce05658edb402",
     "AWS::ElastiCache::SecurityGroup": "075dfa59da275723",
     "AWS::ElastiCache::SecurityGroupIngress": "96d1b4a5bd438d25",
     "AWS::ElastiCache::ServerlessCache": "67ad14ea2425e853",
@@ -627,7 +636,7 @@ types: dict[str, str] = {
     "AWS::GreengrassV2::Deployment": "113077f9583c552f",
     "AWS::GuardDuty::Detector": "609c5ab9768f30a4",
     "AWS::GuardDuty::Filter": "5effc026fb87131d",
-    "AWS::GuardDuty::IPSet": "82e2140b58b00302",
+    "AWS::GuardDuty::IPSet": "2755befa61203d7e",
     "AWS::GuardDuty::MalwareProtectionPlan": "d875ebc427de851e",
     "AWS::GuardDuty::Master": "5115377f51b894ca",
     "AWS::GuardDuty::Member": "4410bf4350c9fdb8",
@@ -897,12 +906,13 @@ types: dict[str, str] = {
     "AWS::ObservabilityAdmin::TelemetryRule": "4ea5670f96981494",
     "AWS::OpenSearchServerless::AccessPolicy": "ec7a348a493d8c4f",
     "AWS::OpenSearchServerless::Collection": "2ee2aaf7421edcad",
+    "AWS::OpenSearchServerless::CollectionGroup": "b6d93309ca936d98",
     "AWS::OpenSearchServerless::Index": "fcc40949c8a1e83a",
     "AWS::OpenSearchServerless::LifecyclePolicy": "71de0a66a6f0daa7",
     "AWS::OpenSearchServerless::SecurityConfig": "4d3e887cb7677f9c",
     "AWS::OpenSearchServerless::SecurityPolicy": "a73437e0f606fd57",
     "AWS::OpenSearchServerless::VpcEndpoint": "e4bcf34472c7a694",
-    "AWS::OpenSearchService::Application": "866ac7c65f261ec4",
+    "AWS::OpenSearchService::Application": "54acd8b539fb7b22",
     "AWS::OpenSearchService::Domain": "9066691d16aebb93",
     "AWS::OpsWorks::App": "508d500b32261320",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment": "4902f6030931194b",
@@ -922,7 +932,7 @@ types: dict[str, str] = {
     "AWS::PCAConnectorAD::Template": "ed0b568c05022bdf",
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry": "756784fc38981208",
     "AWS::PCAConnectorSCEP::Challenge": "66f2129c2055583e",
-    "AWS::PCAConnectorSCEP::Connector": "16c8fa0f3e84b76a",
+    "AWS::PCAConnectorSCEP::Connector": "3985d16f9d690d78",
     "AWS::Panorama::ApplicationInstance": "af397448646f41b5",
     "AWS::Panorama::Package": "4aba76bdd4e652aa",
     "AWS::Panorama::PackageVersion": "019b276ff772790d",
@@ -963,7 +973,7 @@ types: dict[str, str] = {
     "AWS::QuickSight::DataSource": "407708b753626383",
     "AWS::QuickSight::Folder": "4a9e4af92dbcc718",
     "AWS::QuickSight::RefreshSchedule": "0e848e5d85a17427",
-    "AWS::QuickSight::Template": "9f99a52291094b16",
+    "AWS::QuickSight::Template": "bf2e53263bce9387",
     "AWS::QuickSight::Theme": "c85a23cc7ca1d55e",
     "AWS::QuickSight::Topic": "f4d504e353c8a0fc",
     "AWS::QuickSight::VPCConnection": "bb1c6b99877fb6ba",
@@ -1098,7 +1108,7 @@ types: dict[str, str] = {
     "AWS::SQS::QueuePolicy": "8d0c3b8154e71ff3",
     "AWS::SSM::Association": "e5ce83b562338270",
     "AWS::SSM::Document": "fafd81d675e3af92",
-    "AWS::SSM::MaintenanceWindow": "54b31dcf040d1e3b",
+    "AWS::SSM::MaintenanceWindow": "8bcf8299c61efe9b",
     "AWS::SSM::MaintenanceWindowTarget": "1d59aec599d718b8",
     "AWS::SSM::MaintenanceWindowTask": "dbf020e1bce02a1c",
     "AWS::SSM::Parameter": "88998b8e50aa846a",
@@ -1132,7 +1142,7 @@ types: dict[str, str] = {
     "AWS::SageMaker::Image": "1f7b8f5745496bd2",
     "AWS::SageMaker::ImageVersion": "307ec283c9c38549",
     "AWS::SageMaker::InferenceComponent": "bf2b2e27111fb3a4",
-    "AWS::SageMaker::InferenceExperiment": "b19e56ad811b2cbd",
+    "AWS::SageMaker::InferenceExperiment": "a15f7a6adffaf10d",
     "AWS::SageMaker::MlflowTrackingServer": "82716f2317f73364",
     "AWS::SageMaker::Model": "9757bf2bdc6a25ef",
     "AWS::SageMaker::ModelBiasJobDefinition": "1357485edb491230",
@@ -1181,9 +1191,9 @@ types: dict[str, str] = {
     "AWS::ServiceCatalog::CloudFormationProduct": "662186534ff8e643",
     "AWS::ServiceCatalog::CloudFormationProvisionedProduct": "448a377417beb2e5",
     "AWS::ServiceCatalog::LaunchNotificationConstraint": "b7978856af5cccf2",
-    "AWS::ServiceCatalog::LaunchRoleConstraint": "dfc41af30527c286",
+    "AWS::ServiceCatalog::LaunchRoleConstraint": "645835eeed030de3",
     "AWS::ServiceCatalog::LaunchTemplateConstraint": "e457535596ed60a2",
-    "AWS::ServiceCatalog::Portfolio": "2802283288dedb80",
+    "AWS::ServiceCatalog::Portfolio": "3f12b2c638b77209",
     "AWS::ServiceCatalog::PortfolioPrincipalAssociation": "c1655e6cd9e94bc0",
     "AWS::ServiceCatalog::PortfolioProductAssociation": "39311ae1cb0b583e",
     "AWS::ServiceCatalog::PortfolioShare": "c365f2118140f92b",
