@@ -91,7 +91,7 @@ types: dict[str, str] = {
     "AWS::Backup::BackupSelection": "26040166156c899a",
     "AWS::Backup::BackupVault": "695e80a4aaec9275",
     "AWS::Backup::TieringConfiguration": "f16772cf7bc87fe1",
-    "AWS::Batch::ComputeEnvironment": "c04685284080736b",
+    "AWS::Batch::ComputeEnvironment": "90bfbf164c530f34",
     "AWS::Batch::ConsumableResource": "8e12226640545a9a",
     "AWS::Batch::JobDefinition": "8a7ecae4430d86b2",
     "AWS::Batch::JobQueue": "330cfa7e67eefadc",
@@ -133,6 +133,7 @@ types: dict[str, str] = {
     "AWS::CloudFront::StreamingDistribution": "b9728ac9dbd5af28",
     "AWS::CloudTrail::Trail": "7afdcfb6fa95406a",
     "AWS::CloudWatch::Alarm": "0602d31ab163094b",
+    "AWS::CloudWatch::AlarmMuteRule": "8ae4572f5b52e53d",
     "AWS::CloudWatch::AnomalyDetector": "13b8b743191bf50f",
     "AWS::CloudWatch::CompositeAlarm": "2b2200aed34aabc4",
     "AWS::CloudWatch::Dashboard": "423086b5b02bd126",
@@ -188,6 +189,11 @@ types: dict[str, str] = {
     "AWS::DataSync::LocationS3": "b83bd659cd9ae32b",
     "AWS::DataSync::LocationSMB": "afc5e5a2496d1a84",
     "AWS::DataSync::Task": "ec59b72ff72a799c",
+    "AWS::DirectConnect::Connection": "816b9e564bb15a2d",
+    "AWS::DirectConnect::DirectConnectGateway": "064ba92b6e29e1bb",
+    "AWS::DirectConnect::DirectConnectGatewayAssociation": "e8b6eb4a71af1eee",
+    "AWS::DirectConnect::Lag": "5d6f47c1a9673feb",
+    "AWS::DirectConnect::PublicVirtualInterface": "ac13a4f01149c397",
     "AWS::DirectoryService::MicrosoftAD": "9a7cb3c87d0c07fc",
     "AWS::DirectoryService::SimpleAD": "6d2510fa67236f4b",
     "AWS::DocDB::DBCluster": "be6f39b91c56eff9",
@@ -198,10 +204,10 @@ types: dict[str, str] = {
     "AWS::DynamoDB::GlobalTable": "dcad01d68f1b0691",
     "AWS::DynamoDB::Table": "50e57ed2b28d4230",
     "AWS::EC2::CapacityReservation": "1ab29c6314095182",
-    "AWS::EC2::CapacityReservationFleet": "5d448b59c2d73e04",
+    "AWS::EC2::CapacityReservationFleet": "66f529dd9ae70683",
     "AWS::EC2::CustomerGateway": "5c3cdba89933c1e2",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "1a8415e48effd9a9",
+    "AWS::EC2::EC2Fleet": "a6921911281e83cd",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
@@ -216,12 +222,12 @@ types: dict[str, str] = {
     "AWS::EC2::IPAMResourceDiscovery": "0a21294934d111b5",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
     "AWS::EC2::IPAMScope": "f1341090e0e57749",
-    "AWS::EC2::Instance": "7a8c89a99087d7d5",
+    "AWS::EC2::Instance": "a61701d41fad1efa",
     "AWS::EC2::InstanceConnectEndpoint": "ccb7d5f817cc9d24",
     "AWS::EC2::InternetGateway": "4c7c90cb3105c9d8",
     "AWS::EC2::IpPoolRouteTableAssociation": "071b5a1f00936f72",
     "AWS::EC2::KeyPair": "349deb28f79434e4",
-    "AWS::EC2::LaunchTemplate": "51d9c721a02159c3",
+    "AWS::EC2::LaunchTemplate": "dbb4de05d9ee7263",
     "AWS::EC2::NatGateway": "28e80cb1fcf92145",
     "AWS::EC2::NetworkAcl": "41c7ec1cea436cd8",
     "AWS::EC2::NetworkAclEntry": "d4fc9ce8669023f0",
@@ -248,11 +254,11 @@ types: dict[str, str] = {
     "AWS::EC2::TrafficMirrorTarget": "562f502a60abccd6",
     "AWS::EC2::TransitGateway": "bdd0278ecaccd4ae",
     "AWS::EC2::TransitGatewayAttachment": "40111e00bf0df74a",
-    "AWS::EC2::TransitGatewayConnect": "05caf42b9c40a843",
+    "AWS::EC2::TransitGatewayConnect": "f3001456d8e71829",
     "AWS::EC2::TransitGatewayConnectPeer": "27459a628d254042",
     "AWS::EC2::TransitGatewayMeteringPolicy": "4daf1939996f77df",
     "AWS::EC2::TransitGatewayMeteringPolicyEntry": "153b7c0d6fcca798",
-    "AWS::EC2::TransitGatewayMulticastDomain": "8a9fdc16690320b7",
+    "AWS::EC2::TransitGatewayMulticastDomain": "55ac3f0e32f72ab4",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation": "f650430e0bbdcce9",
     "AWS::EC2::TransitGatewayMulticastGroupMember": "fe8c827e156dc451",
     "AWS::EC2::TransitGatewayMulticastGroupSource": "95b20156fbc77eb0",
@@ -285,7 +291,7 @@ types: dict[str, str] = {
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
     "AWS::ECR::Repository": "d569f41026af3be8",
     "AWS::ECR::RepositoryCreationTemplate": "e37496e3eb934872",
-    "AWS::ECS::CapacityProvider": "2fd840d01bf69b36",
+    "AWS::ECS::CapacityProvider": "75072f96ae0bbe21",
     "AWS::ECS::Cluster": "92b09b679d42fc1e",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::PrimaryTaskSet": "d8ea9e906cb85b80",
@@ -296,7 +302,7 @@ types: dict[str, str] = {
     "AWS::EFS::FileSystem": "575ef4f21bc6f9da",
     "AWS::EFS::MountTarget": "562530cf9ce264a6",
     "AWS::EKS::AccessEntry": "6eb6ba186799e7f3",
-    "AWS::EKS::Addon": "f27379fa02ce1e45",
+    "AWS::EKS::Addon": "63cae0a921c6a93d",
     "AWS::EKS::Cluster": "46cd8dea9cf6c5d7",
     "AWS::EKS::FargateProfile": "54a9efe57f089a05",
     "AWS::EKS::IdentityProviderConfig": "77b807192827540b",
@@ -399,11 +405,11 @@ types: dict[str, str] = {
     "AWS::GreengrassV2::Deployment": "113077f9583c552f",
     "AWS::GuardDuty::Detector": "609c5ab9768f30a4",
     "AWS::GuardDuty::Filter": "5effc026fb87131d",
-    "AWS::GuardDuty::IPSet": "82e2140b58b00302",
+    "AWS::GuardDuty::IPSet": "2755befa61203d7e",
     "AWS::GuardDuty::Master": "5115377f51b894ca",
     "AWS::GuardDuty::Member": "4410bf4350c9fdb8",
-    "AWS::GuardDuty::PublishingDestination": "95c6a8d647a77c52",
-    "AWS::GuardDuty::ThreatIntelSet": "09915bee5770f4c9",
+    "AWS::GuardDuty::PublishingDestination": "c0e7c21001df88a4",
+    "AWS::GuardDuty::ThreatIntelSet": "41eb1d839da4d715",
     "AWS::IAM::AccessKey": "72c2d9dd90025459",
     "AWS::IAM::Group": "23f995735d09bdb9",
     "AWS::IAM::GroupPolicy": "afebc6bd2ca04f23",
@@ -508,7 +514,7 @@ types: dict[str, str] = {
     "AWS::Lambda::EventSourceMapping": "80b93fa5c6ca4992",
     "AWS::Lambda::Function": "3a6aacfd45065c20",
     "AWS::Lambda::LayerVersion": "f00fbc621c084236",
-    "AWS::Lambda::LayerVersionPermission": "fe51be1d33332373",
+    "AWS::Lambda::LayerVersionPermission": "3d77aa7f6f48b060",
     "AWS::Lambda::Permission": "a43a5328bea4f6ad",
     "AWS::Lambda::Url": "cd116e62a210bc57",
     "AWS::Lambda::Version": "e7fcd54deb138582",
@@ -551,7 +557,7 @@ types: dict[str, str] = {
     "AWS::NetworkFirewall::VpcEndpointAssociation": "671a5fc51bc59b14",
     "AWS::Oam::Link": "4d4e114e0f615d82",
     "AWS::Oam::Sink": "81957ea027e4c201",
-    "AWS::OpenSearchService::Domain": "1c09878d526db02c",
+    "AWS::OpenSearchService::Domain": "9066691d16aebb93",
     "AWS::OpsWorks::App": "508d500b32261320",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment": "4902f6030931194b",
     "AWS::OpsWorks::Instance": "eb6dd86e61f421da",
@@ -576,7 +582,7 @@ types: dict[str, str] = {
     "AWS::QuickSight::DataSource": "407708b753626383",
     "AWS::QuickSight::Folder": "4a9e4af92dbcc718",
     "AWS::QuickSight::RefreshSchedule": "0e848e5d85a17427",
-    "AWS::QuickSight::Template": "9f99a52291094b16",
+    "AWS::QuickSight::Template": "bf2e53263bce9387",
     "AWS::QuickSight::Theme": "c85a23cc7ca1d55e",
     "AWS::QuickSight::VPCConnection": "bb1c6b99877fb6ba",
     "AWS::RAM::Permission": "978c532747f94c7b",
@@ -638,7 +644,7 @@ types: dict[str, str] = {
     "AWS::S3::AccessPoint": "e8b95810dd8d6917",
     "AWS::S3::Bucket": "f2e96ae4922bbb57",
     "AWS::S3::BucketPolicy": "38ad5b8bd8062535",
-    "AWS::S3::StorageLens": "e20ccca5b946adc3",
+    "AWS::S3::StorageLens": "842abc50870a3bcf",
     "AWS::S3::StorageLensGroup": "a48c03e67d334c14",
     "AWS::S3Express::AccessPoint": "319fc2700104fd70",
     "AWS::S3Express::BucketPolicy": "79c6732ff6204662",
@@ -646,7 +652,7 @@ types: dict[str, str] = {
     "AWS::S3ObjectLambda::AccessPoint": "2d6b2b82a9508114",
     "AWS::S3ObjectLambda::AccessPointPolicy": "fd6328c6c782223a",
     "AWS::S3Tables::Namespace": "148f9286df26a384",
-    "AWS::S3Tables::Table": "a3eed252e01d4a85",
+    "AWS::S3Tables::Table": "06c0bb9325f0bc8c",
     "AWS::S3Tables::TableBucket": "c87800af01ff17ff",
     "AWS::S3Tables::TableBucketPolicy": "8a4df56718b22c4c",
     "AWS::S3Tables::TablePolicy": "a400a63607882bc8",
@@ -660,7 +666,7 @@ types: dict[str, str] = {
     "AWS::SQS::QueuePolicy": "8d0c3b8154e71ff3",
     "AWS::SSM::Association": "e5ce83b562338270",
     "AWS::SSM::Document": "fafd81d675e3af92",
-    "AWS::SSM::MaintenanceWindow": "54b31dcf040d1e3b",
+    "AWS::SSM::MaintenanceWindow": "067c502e88a1f5d2",
     "AWS::SSM::MaintenanceWindowTarget": "1d59aec599d718b8",
     "AWS::SSM::MaintenanceWindowTask": "dbf020e1bce02a1c",
     "AWS::SSM::Parameter": "88998b8e50aa846a",
@@ -679,7 +685,7 @@ types: dict[str, str] = {
     "AWS::SageMaker::Endpoint": "bcd29d1fafd461ae",
     "AWS::SageMaker::EndpointConfig": "7c3a65bd96c2e9a3",
     "AWS::SageMaker::FeatureGroup": "2fd87c841fd87a48",
-    "AWS::SageMaker::Image": "1f7b8f5745496bd2",
+    "AWS::SageMaker::Image": "564da26f07cd2046",
     "AWS::SageMaker::ImageVersion": "307ec283c9c38549",
     "AWS::SageMaker::Model": "9757bf2bdc6a25ef",
     "AWS::SageMaker::ModelCard": "89534938581c1015",
@@ -714,9 +720,9 @@ types: dict[str, str] = {
     "AWS::ServiceCatalog::CloudFormationProduct": "662186534ff8e643",
     "AWS::ServiceCatalog::CloudFormationProvisionedProduct": "448a377417beb2e5",
     "AWS::ServiceCatalog::LaunchNotificationConstraint": "b7978856af5cccf2",
-    "AWS::ServiceCatalog::LaunchRoleConstraint": "dfc41af30527c286",
+    "AWS::ServiceCatalog::LaunchRoleConstraint": "645835eeed030de3",
     "AWS::ServiceCatalog::LaunchTemplateConstraint": "e457535596ed60a2",
-    "AWS::ServiceCatalog::Portfolio": "52a609bb3d2294b5",
+    "AWS::ServiceCatalog::Portfolio": "546acc3272366c1a",
     "AWS::ServiceCatalog::PortfolioPrincipalAssociation": "c1655e6cd9e94bc0",
     "AWS::ServiceCatalog::PortfolioProductAssociation": "39311ae1cb0b583e",
     "AWS::ServiceCatalog::PortfolioShare": "c365f2118140f92b",
@@ -743,7 +749,7 @@ types: dict[str, str] = {
     "AWS::Transfer::WebApp": "146273f9ed9978d6",
     "AWS::Transfer::Workflow": "851674d5732910da",
     "AWS::VerifiedPermissions::Policy": "f7e75c34791cf6a5",
-    "AWS::VerifiedPermissions::PolicyStore": "5883732ea6547044",
+    "AWS::VerifiedPermissions::PolicyStore": "d797894a95fb9d61",
     "AWS::VerifiedPermissions::PolicyTemplate": "067128efc0e8f2eb",
     "AWS::WAF::ByteMatchSet": "bdac58da17fc8f67",
     "AWS::WAF::IPSet": "e9b5a4840b312167",
