@@ -12,7 +12,7 @@ types: dict[str, str] = {
     "AWS::APS::RuleGroupsNamespace": "1898bd2e1a2fc3af",
     "AWS::APS::Scraper": "6d167939ca161a78",
     "AWS::APS::Workspace": "0739c3a13c4ccac6",
-    "AWS::ARCRegionSwitch::Plan": "f86e2a208e3b2f69",
+    "AWS::ARCRegionSwitch::Plan": "a1a2ea55c2fbda5a",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
     "AWS::AccessAnalyzer::Analyzer": "165f750ca8d78dde",
@@ -142,7 +142,7 @@ types: dict[str, str] = {
     "AWS::Backup::RestoreTestingSelection": "d4f6fc7c7d230fb2",
     "AWS::Backup::TieringConfiguration": "f16772cf7bc87fe1",
     "AWS::BackupGateway::Hypervisor": "cd1de2c6ed11afdd",
-    "AWS::Batch::ComputeEnvironment": "c04685284080736b",
+    "AWS::Batch::ComputeEnvironment": "90bfbf164c530f34",
     "AWS::Batch::ConsumableResource": "8e12226640545a9a",
     "AWS::Batch::JobDefinition": "8a7ecae4430d86b2",
     "AWS::Batch::JobQueue": "330cfa7e67eefadc",
@@ -166,10 +166,13 @@ types: dict[str, str] = {
     "AWS::Bedrock::Prompt": "63cb5b7f989bfc36",
     "AWS::Bedrock::PromptVersion": "41e3e79078ba156a",
     "AWS::BedrockAgentCore::BrowserCustom": "b3f585b2b83595e9",
+    "AWS::BedrockAgentCore::BrowserProfile": "dbc879ccd777f559",
     "AWS::BedrockAgentCore::CodeInterpreterCustom": "a4789ce5aa400e99",
+    "AWS::BedrockAgentCore::Evaluator": "3e9c9d4c18875124",
     "AWS::BedrockAgentCore::Gateway": "a629441d622699ce",
     "AWS::BedrockAgentCore::GatewayTarget": "a90255fe32f8754f",
     "AWS::BedrockAgentCore::Memory": "5bcb5948044458bc",
+    "AWS::BedrockAgentCore::OnlineEvaluationConfig": "e3d9c917491a8c1b",
     "AWS::BedrockAgentCore::Runtime": "7f7ce91778cdda1e",
     "AWS::BedrockAgentCore::RuntimeEndpoint": "11ae501ca9679300",
     "AWS::BedrockAgentCore::WorkloadIdentity": "78d4c036021cc12e",
@@ -181,7 +184,7 @@ types: dict[str, str] = {
     "AWS::CE::CostCategory": "02801220bf93ab09",
     "AWS::Cases::CaseRule": "3c901a066e2031a8",
     "AWS::Cases::Domain": "819687c312320180",
-    "AWS::Cases::Field": "575dad6f219c55da",
+    "AWS::Cases::Field": "bc39acc9e67530ac",
     "AWS::Cases::Layout": "f48d9c43985a0937",
     "AWS::Cases::Template": "af733164010ae401",
     "AWS::Cassandra::Keyspace": "0bd2067860b304f2",
@@ -245,8 +248,8 @@ types: dict[str, str] = {
     "AWS::CloudTrail::EventDataStore": "a51aca6f15d716e3",
     "AWS::CloudTrail::ResourcePolicy": "ab2ae9ccbbd62450",
     "AWS::CloudTrail::Trail": "7afdcfb6fa95406a",
-    "AWS::CloudWatch::Alarm": "0602d31ab163094b",
-    "AWS::CloudWatch::AlarmMuteRule": "f0a042f925c1171c",
+    "AWS::CloudWatch::Alarm": "47097fccd085d8c3",
+    "AWS::CloudWatch::AlarmMuteRule": "8ae4572f5b52e53d",
     "AWS::CloudWatch::AnomalyDetector": "13b8b743191bf50f",
     "AWS::CloudWatch::CompositeAlarm": "2b2200aed34aabc4",
     "AWS::CloudWatch::Dashboard": "423086b5b02bd126",
@@ -292,6 +295,7 @@ types: dict[str, str] = {
     "AWS::Cognito::UserPoolUserToGroupAttachment": "642c498727b1c8f4",
     "AWS::Comprehend::DocumentClassifier": "db28a10be8dd6680",
     "AWS::Comprehend::Flywheel": "ca128fe279b194a4",
+    "AWS::ComputeOptimizer::AutomationRule": "6755b5f1b2a77722",
     "AWS::Config::AggregationAuthorization": "af318b77aaceeeaa",
     "AWS::Config::ConfigRule": "907ef12e35734983",
     "AWS::Config::ConfigurationAggregator": "6d45617d9786aeb6",
@@ -313,7 +317,7 @@ types: dict[str, str] = {
     "AWS::Connect::DataTableAttribute": "08713b122feb23e4",
     "AWS::Connect::DataTableRecord": "db6c4d160c0da36f",
     "AWS::Connect::EmailAddress": "807b7160b3385afb",
-    "AWS::Connect::EvaluationForm": "d4ec84ca94cd03eb",
+    "AWS::Connect::EvaluationForm": "703f443754ae5853",
     "AWS::Connect::HoursOfOperation": "c07c23e26b9311e4",
     "AWS::Connect::Instance": "77fc4614538cb79c",
     "AWS::Connect::InstanceStorageConfig": "036e51d554e029ec",
@@ -327,7 +331,7 @@ types: dict[str, str] = {
     "AWS::Connect::RoutingProfile": "fdb02c4cceaed889",
     "AWS::Connect::Rule": "a1bc460a7ddb424f",
     "AWS::Connect::SecurityKey": "e9f93d5d01b7cd8a",
-    "AWS::Connect::SecurityProfile": "798b9caa82f1f569",
+    "AWS::Connect::SecurityProfile": "1e0f4cd763c6cf8a",
     "AWS::Connect::TaskTemplate": "b8fc1c59ecb09672",
     "AWS::Connect::TrafficDistributionGroup": "f1ac9f1d5792c0ec",
     "AWS::Connect::User": "21af5758c82426d4",
@@ -418,6 +422,13 @@ types: dict[str, str] = {
     "AWS::DevOpsGuru::LogAnomalyDetectionIntegration": "c82fe28dc7521465",
     "AWS::DevOpsGuru::NotificationChannel": "2d809460f09a7b45",
     "AWS::DevOpsGuru::ResourceCollection": "d6cf75b9cf367649",
+    "AWS::DirectConnect::Connection": "816b9e564bb15a2d",
+    "AWS::DirectConnect::DirectConnectGateway": "064ba92b6e29e1bb",
+    "AWS::DirectConnect::DirectConnectGatewayAssociation": "e8b6eb4a71af1eee",
+    "AWS::DirectConnect::Lag": "5d6f47c1a9673feb",
+    "AWS::DirectConnect::PrivateVirtualInterface": "6c8c1e1388789e05",
+    "AWS::DirectConnect::PublicVirtualInterface": "ac13a4f01149c397",
+    "AWS::DirectConnect::TransitVirtualInterface": "4cbdabc6ea22d6c4",
     "AWS::DirectoryService::MicrosoftAD": "9a7cb3c87d0c07fc",
     "AWS::DirectoryService::SimpleAD": "6d2510fa67236f4b",
     "AWS::DocDB::DBCluster": "be6f39b91c56eff9",
@@ -425,13 +436,13 @@ types: dict[str, str] = {
     "AWS::DocDB::DBInstance": "253562f270b587ac",
     "AWS::DocDB::DBSubnetGroup": "ccb97a9452b2284d",
     "AWS::DocDB::EventSubscription": "d22815028d03f301",
-    "AWS::DocDB::GlobalCluster": "8a43a2ee7a595e9a",
+    "AWS::DocDB::GlobalCluster": "6cbd1fec2debea5e",
     "AWS::DocDBElastic::Cluster": "28672c1fbb8ef381",
     "AWS::DynamoDB::GlobalTable": "dcad01d68f1b0691",
     "AWS::DynamoDB::Table": "50e57ed2b28d4230",
     "AWS::EC2::CapacityManagerDataExport": "eadbbd5d7fd8fd3c",
     "AWS::EC2::CapacityReservation": "1ab29c6314095182",
-    "AWS::EC2::CapacityReservationFleet": "5d448b59c2d73e04",
+    "AWS::EC2::CapacityReservationFleet": "66f529dd9ae70683",
     "AWS::EC2::CarrierGateway": "ac1f397e6adda506",
     "AWS::EC2::ClientVpnAuthorizationRule": "9dfbd181c3c5a54c",
     "AWS::EC2::ClientVpnEndpoint": "d132f32844d7e05e",
@@ -439,7 +450,7 @@ types: dict[str, str] = {
     "AWS::EC2::ClientVpnTargetNetworkAssociation": "d69233d655faf0f6",
     "AWS::EC2::CustomerGateway": "4003177e29b1dfc5",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "1a8415e48effd9a9",
+    "AWS::EC2::EC2Fleet": "a6921911281e83cd",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
@@ -455,12 +466,12 @@ types: dict[str, str] = {
     "AWS::EC2::IPAMResourceDiscovery": "0a21294934d111b5",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
     "AWS::EC2::IPAMScope": "f1341090e0e57749",
-    "AWS::EC2::Instance": "7a8c89a99087d7d5",
+    "AWS::EC2::Instance": "a61701d41fad1efa",
     "AWS::EC2::InstanceConnectEndpoint": "ccb7d5f817cc9d24",
     "AWS::EC2::InternetGateway": "4c7c90cb3105c9d8",
     "AWS::EC2::IpPoolRouteTableAssociation": "071b5a1f00936f72",
     "AWS::EC2::KeyPair": "349deb28f79434e4",
-    "AWS::EC2::LaunchTemplate": "51d9c721a02159c3",
+    "AWS::EC2::LaunchTemplate": "dbb4de05d9ee7263",
     "AWS::EC2::LocalGatewayRoute": "b50d8737e0b1ea90",
     "AWS::EC2::LocalGatewayRouteTable": "6892bdd3f1f99df6",
     "AWS::EC2::LocalGatewayRouteTableVPCAssociation": "b1d6ce946dcb69b8",
@@ -540,15 +551,15 @@ types: dict[str, str] = {
     "AWS::EC2::VerifiedAccessTrustProvider": "4220d49771042d48",
     "AWS::EC2::Volume": "3385669f1c48cc6c",
     "AWS::EC2::VolumeAttachment": "1f1ab62c0d6b0fdb",
-    "AWS::ECR::PullThroughCacheRule": "030a391bf2a90ed4",
+    "AWS::ECR::PullThroughCacheRule": "bab1b3208aa431ab",
     "AWS::ECR::PullTimeUpdateExclusion": "67ad05acb3cd4d21",
     "AWS::ECR::RegistryPolicy": "a36a04f4454cafc2",
     "AWS::ECR::RegistryScanningConfiguration": "68012043447b437a",
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
-    "AWS::ECR::Repository": "d569f41026af3be8",
+    "AWS::ECR::Repository": "f436b8d080c711a7",
     "AWS::ECR::RepositoryCreationTemplate": "e37496e3eb934872",
     "AWS::ECR::SigningConfiguration": "c502bcdb31b67cc1",
-    "AWS::ECS::CapacityProvider": "2fd840d01bf69b36",
+    "AWS::ECS::CapacityProvider": "75072f96ae0bbe21",
     "AWS::ECS::Cluster": "92b09b679d42fc1e",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::ExpressGatewayService": "03b7c9db813057d9",
@@ -583,7 +594,7 @@ types: dict[str, str] = {
     "AWS::ElastiCache::CacheCluster": "1220b6bbd633ae68",
     "AWS::ElastiCache::GlobalReplicationGroup": "2af3062bf5b2cf7f",
     "AWS::ElastiCache::ParameterGroup": "b0e1dec3cd05f739",
-    "AWS::ElastiCache::ReplicationGroup": "0b94d00dcdccdba6",
+    "AWS::ElastiCache::ReplicationGroup": "a7cce05658edb402",
     "AWS::ElastiCache::SecurityGroup": "075dfa59da275723",
     "AWS::ElastiCache::SecurityGroupIngress": "96d1b4a5bd438d25",
     "AWS::ElastiCache::ServerlessCache": "67ad14ea2425e853",
@@ -703,7 +714,7 @@ types: dict[str, str] = {
     "AWS::GroundStation::MissionProfile": "32655ab91f6a315f",
     "AWS::GuardDuty::Detector": "609c5ab9768f30a4",
     "AWS::GuardDuty::Filter": "5effc026fb87131d",
-    "AWS::GuardDuty::IPSet": "82e2140b58b00302",
+    "AWS::GuardDuty::IPSet": "2755befa61203d7e",
     "AWS::GuardDuty::MalwareProtectionPlan": "d875ebc427de851e",
     "AWS::GuardDuty::Master": "5115377f51b894ca",
     "AWS::GuardDuty::Member": "4410bf4350c9fdb8",
@@ -953,8 +964,8 @@ types: dict[str, str] = {
     "AWS::MediaLive::SdiSource": "0758f27a64ded787",
     "AWS::MediaLive::SignalMap": "4469cefa6a45f1f7",
     "AWS::MediaPackage::Asset": "46a05885cb8e8a23",
-    "AWS::MediaPackage::Channel": "e7456b39d936b909",
-    "AWS::MediaPackage::OriginEndpoint": "35ba5a2f6d533dd0",
+    "AWS::MediaPackage::Channel": "9ca2abdae4994be0",
+    "AWS::MediaPackage::OriginEndpoint": "6eaddb59505ff8fe",
     "AWS::MediaPackage::PackagingConfiguration": "381cdf03053e7a94",
     "AWS::MediaPackage::PackagingGroup": "ef7cc14fb78ab5d0",
     "AWS::MediaPackageV2::Channel": "62a1a362e9e8f627",
@@ -1014,7 +1025,7 @@ types: dict[str, str] = {
     "AWS::OSIS::Pipeline": "7d12e06885198d09",
     "AWS::Oam::Link": "4d4e114e0f615d82",
     "AWS::Oam::Sink": "81957ea027e4c201",
-    "AWS::ObservabilityAdmin::OrganizationCentralizationRule": "6921de30f2cef3a3",
+    "AWS::ObservabilityAdmin::OrganizationCentralizationRule": "fcbae6aa87cf8be4",
     "AWS::ObservabilityAdmin::OrganizationTelemetryRule": "b1afe16ecb07efd3",
     "AWS::ObservabilityAdmin::S3TableIntegration": "9dcd4f79cf41f229",
     "AWS::ObservabilityAdmin::TelemetryPipelines": "1acc5affc6615ad2",
@@ -1028,13 +1039,13 @@ types: dict[str, str] = {
     "AWS::Omics::WorkflowVersion": "293e6e45ad5e99b1",
     "AWS::OpenSearchServerless::AccessPolicy": "ec7a348a493d8c4f",
     "AWS::OpenSearchServerless::Collection": "2ee2aaf7421edcad",
-    "AWS::OpenSearchServerless::CollectionGroup": "337b230a84bb38e9",
+    "AWS::OpenSearchServerless::CollectionGroup": "b6d93309ca936d98",
     "AWS::OpenSearchServerless::Index": "fcc40949c8a1e83a",
     "AWS::OpenSearchServerless::LifecyclePolicy": "71de0a66a6f0daa7",
     "AWS::OpenSearchServerless::SecurityConfig": "4d3e887cb7677f9c",
     "AWS::OpenSearchServerless::SecurityPolicy": "a73437e0f606fd57",
     "AWS::OpenSearchServerless::VpcEndpoint": "e4bcf34472c7a694",
-    "AWS::OpenSearchService::Application": "866ac7c65f261ec4",
+    "AWS::OpenSearchService::Application": "54acd8b539fb7b22",
     "AWS::OpenSearchService::Domain": "9066691d16aebb93",
     "AWS::OpsWorks::App": "508d500b32261320",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment": "4902f6030931194b",
@@ -1054,7 +1065,7 @@ types: dict[str, str] = {
     "AWS::PCAConnectorAD::Template": "ed0b568c05022bdf",
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry": "756784fc38981208",
     "AWS::PCAConnectorSCEP::Challenge": "66f2129c2055583e",
-    "AWS::PCAConnectorSCEP::Connector": "9cbd2b6a05e6eb0d",
+    "AWS::PCAConnectorSCEP::Connector": "3985d16f9d690d78",
     "AWS::PCS::Cluster": "ae1d815216872864",
     "AWS::PCS::ComputeNodeGroup": "18c1af5cf4154c64",
     "AWS::PCS::Queue": "beffbb3966cc89c2",
@@ -1097,7 +1108,7 @@ types: dict[str, str] = {
     "AWS::QuickSight::CustomPermissions": "da6da182c0c23fb4",
     "AWS::QuickSight::Dashboard": "b1b7368590994f86",
     "AWS::QuickSight::DataSet": "29bb159e7e1e87fc",
-    "AWS::QuickSight::DataSource": "407708b753626383",
+    "AWS::QuickSight::DataSource": "00002f3b004dba6b",
     "AWS::QuickSight::Folder": "4a9e4af92dbcc718",
     "AWS::QuickSight::RefreshSchedule": "0e848e5d85a17427",
     "AWS::QuickSight::Template": "bf2e53263bce9387",
@@ -1242,7 +1253,7 @@ types: dict[str, str] = {
     "AWS::SQS::QueuePolicy": "8d0c3b8154e71ff3",
     "AWS::SSM::Association": "e5ce83b562338270",
     "AWS::SSM::Document": "fafd81d675e3af92",
-    "AWS::SSM::MaintenanceWindow": "54b31dcf040d1e3b",
+    "AWS::SSM::MaintenanceWindow": "067c502e88a1f5d2",
     "AWS::SSM::MaintenanceWindowTarget": "1d59aec599d718b8",
     "AWS::SSM::MaintenanceWindowTask": "dbf020e1bce02a1c",
     "AWS::SSM::Parameter": "88998b8e50aa846a",
@@ -1275,10 +1286,10 @@ types: dict[str, str] = {
     "AWS::SageMaker::Endpoint": "4796aad2d97343d6",
     "AWS::SageMaker::EndpointConfig": "7c3a65bd96c2e9a3",
     "AWS::SageMaker::FeatureGroup": "2fd87c841fd87a48",
-    "AWS::SageMaker::Image": "1f7b8f5745496bd2",
+    "AWS::SageMaker::Image": "564da26f07cd2046",
     "AWS::SageMaker::ImageVersion": "307ec283c9c38549",
     "AWS::SageMaker::InferenceComponent": "bf2b2e27111fb3a4",
-    "AWS::SageMaker::InferenceExperiment": "b19e56ad811b2cbd",
+    "AWS::SageMaker::InferenceExperiment": "a15f7a6adffaf10d",
     "AWS::SageMaker::MlflowTrackingServer": "82716f2317f73364",
     "AWS::SageMaker::Model": "9757bf2bdc6a25ef",
     "AWS::SageMaker::ModelBiasJobDefinition": "1357485edb491230",
@@ -1327,9 +1338,9 @@ types: dict[str, str] = {
     "AWS::ServiceCatalog::CloudFormationProduct": "662186534ff8e643",
     "AWS::ServiceCatalog::CloudFormationProvisionedProduct": "448a377417beb2e5",
     "AWS::ServiceCatalog::LaunchNotificationConstraint": "b7978856af5cccf2",
-    "AWS::ServiceCatalog::LaunchRoleConstraint": "bb36eb75073f92ad",
+    "AWS::ServiceCatalog::LaunchRoleConstraint": "645835eeed030de3",
     "AWS::ServiceCatalog::LaunchTemplateConstraint": "e457535596ed60a2",
-    "AWS::ServiceCatalog::Portfolio": "2802283288dedb80",
+    "AWS::ServiceCatalog::Portfolio": "546acc3272366c1a",
     "AWS::ServiceCatalog::PortfolioPrincipalAssociation": "c1655e6cd9e94bc0",
     "AWS::ServiceCatalog::PortfolioProductAssociation": "39311ae1cb0b583e",
     "AWS::ServiceCatalog::PortfolioShare": "c365f2118140f92b",
