@@ -10,7 +10,7 @@ types: dict[str, str] = {
     "AWS::APS::ResourcePolicy": "da0d17341b025c5d",
     "AWS::APS::RuleGroupsNamespace": "1898bd2e1a2fc3af",
     "AWS::APS::Workspace": "0739c3a13c4ccac6",
-    "AWS::ARCRegionSwitch::Plan": "f86e2a208e3b2f69",
+    "AWS::ARCRegionSwitch::Plan": "a1a2ea55c2fbda5a",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
     "AWS::AccessAnalyzer::Analyzer": "165f750ca8d78dde",
@@ -146,7 +146,7 @@ types: dict[str, str] = {
     "AWS::CloudTrail::ResourcePolicy": "ab2ae9ccbbd62450",
     "AWS::CloudTrail::Trail": "7afdcfb6fa95406a",
     "AWS::CloudWatch::Alarm": "0602d31ab163094b",
-    "AWS::CloudWatch::AlarmMuteRule": "f0a042f925c1171c",
+    "AWS::CloudWatch::AlarmMuteRule": "8ae4572f5b52e53d",
     "AWS::CloudWatch::AnomalyDetector": "13b8b743191bf50f",
     "AWS::CloudWatch::CompositeAlarm": "2b2200aed34aabc4",
     "AWS::CloudWatch::Dashboard": "423086b5b02bd126",
@@ -245,6 +245,13 @@ types: dict[str, str] = {
     "AWS::Detective::Graph": "dbed0b7e7b29e1e6",
     "AWS::Detective::MemberInvitation": "86355f574dcf77f5",
     "AWS::Detective::OrganizationAdmin": "28db50ef7caf9609",
+    "AWS::DirectConnect::Connection": "816b9e564bb15a2d",
+    "AWS::DirectConnect::DirectConnectGateway": "064ba92b6e29e1bb",
+    "AWS::DirectConnect::DirectConnectGatewayAssociation": "e8b6eb4a71af1eee",
+    "AWS::DirectConnect::Lag": "5d6f47c1a9673feb",
+    "AWS::DirectConnect::PrivateVirtualInterface": "6c8c1e1388789e05",
+    "AWS::DirectConnect::PublicVirtualInterface": "ac13a4f01149c397",
+    "AWS::DirectConnect::TransitVirtualInterface": "4cbdabc6ea22d6c4",
     "AWS::DirectoryService::MicrosoftAD": "9a7cb3c87d0c07fc",
     "AWS::DirectoryService::SimpleAD": "6d2510fa67236f4b",
     "AWS::DocDB::DBCluster": "be6f39b91c56eff9",
@@ -256,14 +263,14 @@ types: dict[str, str] = {
     "AWS::DynamoDB::GlobalTable": "dcad01d68f1b0691",
     "AWS::DynamoDB::Table": "50e57ed2b28d4230",
     "AWS::EC2::CapacityReservation": "1ab29c6314095182",
-    "AWS::EC2::CapacityReservationFleet": "5d448b59c2d73e04",
+    "AWS::EC2::CapacityReservationFleet": "66f529dd9ae70683",
     "AWS::EC2::ClientVpnAuthorizationRule": "09dec539b3c3f428",
     "AWS::EC2::ClientVpnEndpoint": "d132f32844d7e05e",
     "AWS::EC2::ClientVpnRoute": "f1d130776f4e1473",
     "AWS::EC2::ClientVpnTargetNetworkAssociation": "d69233d655faf0f6",
     "AWS::EC2::CustomerGateway": "4003177e29b1dfc5",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "1a8415e48effd9a9",
+    "AWS::EC2::EC2Fleet": "a6921911281e83cd",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
@@ -279,12 +286,12 @@ types: dict[str, str] = {
     "AWS::EC2::IPAMResourceDiscovery": "0a21294934d111b5",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
     "AWS::EC2::IPAMScope": "f1341090e0e57749",
-    "AWS::EC2::Instance": "7a8c89a99087d7d5",
+    "AWS::EC2::Instance": "a61701d41fad1efa",
     "AWS::EC2::InstanceConnectEndpoint": "ccb7d5f817cc9d24",
     "AWS::EC2::InternetGateway": "4c7c90cb3105c9d8",
     "AWS::EC2::IpPoolRouteTableAssociation": "071b5a1f00936f72",
     "AWS::EC2::KeyPair": "349deb28f79434e4",
-    "AWS::EC2::LaunchTemplate": "dc7d758834e70fcb",
+    "AWS::EC2::LaunchTemplate": "06d084db5ee3142a",
     "AWS::EC2::LocalGatewayRoute": "b50d8737e0b1ea90",
     "AWS::EC2::LocalGatewayRouteTable": "6892bdd3f1f99df6",
     "AWS::EC2::LocalGatewayRouteTableVPCAssociation": "b1d6ce946dcb69b8",
@@ -338,6 +345,7 @@ types: dict[str, str] = {
     "AWS::EC2::VPCBlockPublicAccessOptions": "1227e027d1c429f9",
     "AWS::EC2::VPCCidrBlock": "2ab876850f9f6c40",
     "AWS::EC2::VPCDHCPOptionsAssociation": "f803bdbad7d930d1",
+    "AWS::EC2::VPCEncryptionControl": "0dff101542854d6c",
     "AWS::EC2::VPCEndpoint": "1ece9f120d9da74a",
     "AWS::EC2::VPCEndpointConnectionNotification": "4d7f63de5d4c3a2e",
     "AWS::EC2::VPCEndpointService": "150eafe6174fc552",
@@ -362,7 +370,7 @@ types: dict[str, str] = {
     "AWS::ECR::Repository": "d569f41026af3be8",
     "AWS::ECR::RepositoryCreationTemplate": "e37496e3eb934872",
     "AWS::ECR::SigningConfiguration": "c502bcdb31b67cc1",
-    "AWS::ECS::CapacityProvider": "2fd840d01bf69b36",
+    "AWS::ECS::CapacityProvider": "75072f96ae0bbe21",
     "AWS::ECS::Cluster": "92b09b679d42fc1e",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::PrimaryTaskSet": "d8ea9e906cb85b80",
@@ -471,11 +479,11 @@ types: dict[str, str] = {
     "AWS::GreengrassV2::Deployment": "113077f9583c552f",
     "AWS::GuardDuty::Detector": "609c5ab9768f30a4",
     "AWS::GuardDuty::Filter": "5effc026fb87131d",
-    "AWS::GuardDuty::IPSet": "82e2140b58b00302",
+    "AWS::GuardDuty::IPSet": "2755befa61203d7e",
     "AWS::GuardDuty::MalwareProtectionPlan": "d875ebc427de851e",
     "AWS::GuardDuty::Master": "5115377f51b894ca",
     "AWS::GuardDuty::Member": "4410bf4350c9fdb8",
-    "AWS::GuardDuty::PublishingDestination": "95c6a8d647a77c52",
+    "AWS::GuardDuty::PublishingDestination": "c0e7c21001df88a4",
     "AWS::GuardDuty::ThreatIntelSet": "41eb1d839da4d715",
     "AWS::IAM::AccessKey": "72c2d9dd90025459",
     "AWS::IAM::Group": "23f995735d09bdb9",
@@ -582,7 +590,7 @@ types: dict[str, str] = {
     "AWS::Lambda::CodeSigningConfig": "078214085a4c3669",
     "AWS::Lambda::EventInvokeConfig": "eb90a4c91675fe09",
     "AWS::Lambda::EventSourceMapping": "3f0bfc179eb7f0c0",
-    "AWS::Lambda::Function": "7b0bc796980cb6c2",
+    "AWS::Lambda::Function": "3a6aacfd45065c20",
     "AWS::Lambda::LayerVersion": "f00fbc621c084236",
     "AWS::Lambda::LayerVersionPermission": "fe51be1d33332373",
     "AWS::Lambda::Permission": "a43a5328bea4f6ad",
@@ -655,6 +663,7 @@ types: dict[str, str] = {
     "AWS::Oam::Sink": "81957ea027e4c201",
     "AWS::OpenSearchServerless::AccessPolicy": "ec7a348a493d8c4f",
     "AWS::OpenSearchServerless::Collection": "2ee2aaf7421edcad",
+    "AWS::OpenSearchServerless::CollectionGroup": "b6d93309ca936d98",
     "AWS::OpenSearchServerless::Index": "fcc40949c8a1e83a",
     "AWS::OpenSearchServerless::LifecyclePolicy": "71de0a66a6f0daa7",
     "AWS::OpenSearchServerless::SecurityConfig": "696c960e6bde9f95",
@@ -673,7 +682,7 @@ types: dict[str, str] = {
     "AWS::Organizations::Policy": "91a30b5718ac046b",
     "AWS::Organizations::ResourcePolicy": "44e0f38bebacad2e",
     "AWS::PCAConnectorSCEP::Challenge": "66f2129c2055583e",
-    "AWS::PCAConnectorSCEP::Connector": "9cbd2b6a05e6eb0d",
+    "AWS::PCAConnectorSCEP::Connector": "3985d16f9d690d78",
     "AWS::PCS::Cluster": "ae1d815216872864",
     "AWS::PCS::ComputeNodeGroup": "18c1af5cf4154c64",
     "AWS::PCS::Queue": "beffbb3966cc89c2",
@@ -776,6 +785,11 @@ types: dict[str, str] = {
     "AWS::S3Outposts::Bucket": "1dda72967f283796",
     "AWS::S3Outposts::BucketPolicy": "29126ab2fb9793f6",
     "AWS::S3Outposts::Endpoint": "323c92664ebd7f95",
+    "AWS::S3Tables::Namespace": "148f9286df26a384",
+    "AWS::S3Tables::Table": "06c0bb9325f0bc8c",
+    "AWS::S3Tables::TableBucket": "c87800af01ff17ff",
+    "AWS::S3Tables::TableBucketPolicy": "8a4df56718b22c4c",
+    "AWS::S3Tables::TablePolicy": "a400a63607882bc8",
     "AWS::SDB::Domain": "48c38397df169b43",
     "AWS::SES::ConfigurationSet": "5d4781bc5cccba7b",
     "AWS::SES::ConfigurationSetEventDestination": "f4e74b1d7e859c34",
@@ -800,14 +814,14 @@ types: dict[str, str] = {
     "AWS::SQS::QueuePolicy": "8d0c3b8154e71ff3",
     "AWS::SSM::Association": "e5ce83b562338270",
     "AWS::SSM::Document": "fafd81d675e3af92",
-    "AWS::SSM::MaintenanceWindow": "54b31dcf040d1e3b",
+    "AWS::SSM::MaintenanceWindow": "8bcf8299c61efe9b",
     "AWS::SSM::MaintenanceWindowTarget": "11fef846e87339e2",
     "AWS::SSM::MaintenanceWindowTask": "9564648c0c7d8e63",
     "AWS::SSM::Parameter": "88998b8e50aa846a",
     "AWS::SSM::PatchBaseline": "43cce065b6753223",
     "AWS::SSM::ResourceDataSync": "f92ce1aa6674b7f2",
     "AWS::SSM::ResourcePolicy": "ffffac06ef7550b0",
-    "AWS::SSMGuiConnect::Preferences": "567ede2077831e62",
+    "AWS::SSMGuiConnect::Preferences": "375a013f12938691",
     "AWS::SSO::Application": "996ad386536ff750",
     "AWS::SSO::ApplicationAssignment": "ae6daf9e56a38982",
     "AWS::SSO::Assignment": "3e0b05f0a3cba8d8",
@@ -859,9 +873,9 @@ types: dict[str, str] = {
     "AWS::ServiceCatalog::CloudFormationProduct": "662186534ff8e643",
     "AWS::ServiceCatalog::CloudFormationProvisionedProduct": "448a377417beb2e5",
     "AWS::ServiceCatalog::LaunchNotificationConstraint": "2c20300ca9670d89",
-    "AWS::ServiceCatalog::LaunchRoleConstraint": "dfc41af30527c286",
+    "AWS::ServiceCatalog::LaunchRoleConstraint": "e953e967aeda94a8",
     "AWS::ServiceCatalog::LaunchTemplateConstraint": "5ac01f0416f9943e",
-    "AWS::ServiceCatalog::Portfolio": "52a609bb3d2294b5",
+    "AWS::ServiceCatalog::Portfolio": "4a1c306059a85c39",
     "AWS::ServiceCatalog::PortfolioPrincipalAssociation": "0484f16f0b9b75cc",
     "AWS::ServiceCatalog::PortfolioProductAssociation": "30a77136cc284746",
     "AWS::ServiceCatalog::PortfolioShare": "7cba6e0bf8041555",
