@@ -11,7 +11,7 @@ types: dict[str, str] = {
     "AWS::APS::RuleGroupsNamespace": "1898bd2e1a2fc3af",
     "AWS::APS::Scraper": "6d167939ca161a78",
     "AWS::APS::Workspace": "0739c3a13c4ccac6",
-    "AWS::ARCRegionSwitch::Plan": "f86e2a208e3b2f69",
+    "AWS::ARCRegionSwitch::Plan": "a1a2ea55c2fbda5a",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
     "AWS::AccessAnalyzer::Analyzer": "165f750ca8d78dde",
@@ -103,6 +103,7 @@ types: dict[str, str] = {
     "AWS::ApplicationSignals::Discovery": "2bbcdf020ea7fc15",
     "AWS::ApplicationSignals::GroupingConfiguration": "d6ba1088512bf212",
     "AWS::ApplicationSignals::ServiceLevelObjective": "148bbf048d668735",
+    "AWS::Athena::CapacityReservation": "cf670cf0253b02eb",
     "AWS::Athena::DataCatalog": "72b7e9ce721875ee",
     "AWS::Athena::NamedQuery": "1fd9b221f87bab5d",
     "AWS::Athena::PreparedStatement": "efe18f0108881514",
@@ -192,7 +193,7 @@ types: dict[str, str] = {
     "AWS::CloudTrail::ResourcePolicy": "ab2ae9ccbbd62450",
     "AWS::CloudTrail::Trail": "7afdcfb6fa95406a",
     "AWS::CloudWatch::Alarm": "0602d31ab163094b",
-    "AWS::CloudWatch::AlarmMuteRule": "f0a042f925c1171c",
+    "AWS::CloudWatch::AlarmMuteRule": "8ae4572f5b52e53d",
     "AWS::CloudWatch::AnomalyDetector": "13b8b743191bf50f",
     "AWS::CloudWatch::CompositeAlarm": "2b2200aed34aabc4",
     "AWS::CloudWatch::Dashboard": "423086b5b02bd126",
@@ -230,6 +231,7 @@ types: dict[str, str] = {
     "AWS::Cognito::UserPoolUICustomizationAttachment": "9a793e05ae357b1c",
     "AWS::Cognito::UserPoolUser": "61780cf8beb842dc",
     "AWS::Cognito::UserPoolUserToGroupAttachment": "642c498727b1c8f4",
+    "AWS::ComputeOptimizer::AutomationRule": "6755b5f1b2a77722",
     "AWS::Config::AggregationAuthorization": "af318b77aaceeeaa",
     "AWS::Config::ConfigRule": "907ef12e35734983",
     "AWS::Config::ConfigurationAggregator": "6d45617d9786aeb6",
@@ -283,20 +285,27 @@ types: dict[str, str] = {
     "AWS::DevOpsGuru::LogAnomalyDetectionIntegration": "c82fe28dc7521465",
     "AWS::DevOpsGuru::NotificationChannel": "2d809460f09a7b45",
     "AWS::DevOpsGuru::ResourceCollection": "d6cf75b9cf367649",
+    "AWS::DirectConnect::Connection": "816b9e564bb15a2d",
+    "AWS::DirectConnect::DirectConnectGateway": "064ba92b6e29e1bb",
+    "AWS::DirectConnect::DirectConnectGatewayAssociation": "e8b6eb4a71af1eee",
+    "AWS::DirectConnect::Lag": "5d6f47c1a9673feb",
+    "AWS::DirectConnect::PrivateVirtualInterface": "6c8c1e1388789e05",
+    "AWS::DirectConnect::PublicVirtualInterface": "ac13a4f01149c397",
+    "AWS::DirectConnect::TransitVirtualInterface": "4cbdabc6ea22d6c4",
     "AWS::DirectoryService::MicrosoftAD": "9a7cb3c87d0c07fc",
     "AWS::DirectoryService::SimpleAD": "6d2510fa67236f4b",
     "AWS::DynamoDB::GlobalTable": "dcad01d68f1b0691",
     "AWS::DynamoDB::Table": "50e57ed2b28d4230",
     "AWS::EC2::CapacityManagerDataExport": "eadbbd5d7fd8fd3c",
     "AWS::EC2::CapacityReservation": "1ab29c6314095182",
-    "AWS::EC2::CapacityReservationFleet": "5d448b59c2d73e04",
+    "AWS::EC2::CapacityReservationFleet": "66f529dd9ae70683",
     "AWS::EC2::ClientVpnAuthorizationRule": "9dfbd181c3c5a54c",
     "AWS::EC2::ClientVpnEndpoint": "d132f32844d7e05e",
     "AWS::EC2::ClientVpnRoute": "f1d130776f4e1473",
     "AWS::EC2::ClientVpnTargetNetworkAssociation": "d69233d655faf0f6",
     "AWS::EC2::CustomerGateway": "4003177e29b1dfc5",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "1a8415e48effd9a9",
+    "AWS::EC2::EC2Fleet": "a6921911281e83cd",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
@@ -312,12 +321,12 @@ types: dict[str, str] = {
     "AWS::EC2::IPAMResourceDiscovery": "0a21294934d111b5",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
     "AWS::EC2::IPAMScope": "f1341090e0e57749",
-    "AWS::EC2::Instance": "7a8c89a99087d7d5",
+    "AWS::EC2::Instance": "a61701d41fad1efa",
     "AWS::EC2::InstanceConnectEndpoint": "ccb7d5f817cc9d24",
     "AWS::EC2::InternetGateway": "4c7c90cb3105c9d8",
     "AWS::EC2::IpPoolRouteTableAssociation": "071b5a1f00936f72",
     "AWS::EC2::KeyPair": "349deb28f79434e4",
-    "AWS::EC2::LaunchTemplate": "51d9c721a02159c3",
+    "AWS::EC2::LaunchTemplate": "dbb4de05d9ee7263",
     "AWS::EC2::LocalGatewayRoute": "b50d8737e0b1ea90",
     "AWS::EC2::LocalGatewayRouteTable": "6892bdd3f1f99df6",
     "AWS::EC2::LocalGatewayRouteTableVPCAssociation": "b1d6ce946dcb69b8",
@@ -387,7 +396,7 @@ types: dict[str, str] = {
     "AWS::EC2::VPCGatewayAttachment": "1dc77043848e8e94",
     "AWS::EC2::VPCPeeringConnection": "41b9860245304058",
     "AWS::EC2::VPNConcentrator": "78aca3962b6da301",
-    "AWS::EC2::VPNConnection": "3bf3a2c97e027241",
+    "AWS::EC2::VPNConnection": "64de71e4f82fffe6",
     "AWS::EC2::VPNConnectionRoute": "00194e67a2d7f53d",
     "AWS::EC2::VPNGateway": "1e2f029e99547e1a",
     "AWS::EC2::VPNGatewayRoutePropagation": "5e03d41fa9dc15b9",
@@ -397,15 +406,15 @@ types: dict[str, str] = {
     "AWS::EC2::VerifiedAccessTrustProvider": "4220d49771042d48",
     "AWS::EC2::Volume": "3385669f1c48cc6c",
     "AWS::EC2::VolumeAttachment": "1f1ab62c0d6b0fdb",
-    "AWS::ECR::PullThroughCacheRule": "030a391bf2a90ed4",
+    "AWS::ECR::PullThroughCacheRule": "bab1b3208aa431ab",
     "AWS::ECR::PullTimeUpdateExclusion": "67ad05acb3cd4d21",
     "AWS::ECR::RegistryPolicy": "a36a04f4454cafc2",
     "AWS::ECR::RegistryScanningConfiguration": "68012043447b437a",
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
-    "AWS::ECR::Repository": "d569f41026af3be8",
+    "AWS::ECR::Repository": "f436b8d080c711a7",
     "AWS::ECR::RepositoryCreationTemplate": "e37496e3eb934872",
     "AWS::ECR::SigningConfiguration": "c502bcdb31b67cc1",
-    "AWS::ECS::CapacityProvider": "2fd840d01bf69b36",
+    "AWS::ECS::CapacityProvider": "75072f96ae0bbe21",
     "AWS::ECS::Cluster": "92b09b679d42fc1e",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::ExpressGatewayService": "03b7c9db813057d9",
@@ -440,7 +449,7 @@ types: dict[str, str] = {
     "AWS::ElastiCache::CacheCluster": "1220b6bbd633ae68",
     "AWS::ElastiCache::GlobalReplicationGroup": "2af3062bf5b2cf7f",
     "AWS::ElastiCache::ParameterGroup": "b0e1dec3cd05f739",
-    "AWS::ElastiCache::ReplicationGroup": "0b94d00dcdccdba6",
+    "AWS::ElastiCache::ReplicationGroup": "a7cce05658edb402",
     "AWS::ElastiCache::SecurityGroup": "075dfa59da275723",
     "AWS::ElastiCache::SecurityGroupIngress": "96d1b4a5bd438d25",
     "AWS::ElastiCache::ServerlessCache": "67ad14ea2425e853",
@@ -535,7 +544,7 @@ types: dict[str, str] = {
     "AWS::Greengrass::SubscriptionDefinitionVersion": "d187f3a18e399825",
     "AWS::GuardDuty::Detector": "609c5ab9768f30a4",
     "AWS::GuardDuty::Filter": "5effc026fb87131d",
-    "AWS::GuardDuty::IPSet": "82e2140b58b00302",
+    "AWS::GuardDuty::IPSet": "2755befa61203d7e",
     "AWS::GuardDuty::MalwareProtectionPlan": "d875ebc427de851e",
     "AWS::GuardDuty::Master": "5115377f51b894ca",
     "AWS::GuardDuty::Member": "4410bf4350c9fdb8",
@@ -745,12 +754,13 @@ types: dict[str, str] = {
     "AWS::ObservabilityAdmin::TelemetryRule": "4ea5670f96981494",
     "AWS::OpenSearchServerless::AccessPolicy": "ec7a348a493d8c4f",
     "AWS::OpenSearchServerless::Collection": "2ee2aaf7421edcad",
+    "AWS::OpenSearchServerless::CollectionGroup": "b6d93309ca936d98",
     "AWS::OpenSearchServerless::Index": "fcc40949c8a1e83a",
     "AWS::OpenSearchServerless::LifecyclePolicy": "71de0a66a6f0daa7",
     "AWS::OpenSearchServerless::SecurityConfig": "4d3e887cb7677f9c",
     "AWS::OpenSearchServerless::SecurityPolicy": "a73437e0f606fd57",
     "AWS::OpenSearchServerless::VpcEndpoint": "e4bcf34472c7a694",
-    "AWS::OpenSearchService::Application": "866ac7c65f261ec4",
+    "AWS::OpenSearchService::Application": "54acd8b539fb7b22",
     "AWS::OpenSearchService::Domain": "9066691d16aebb93",
     "AWS::OpsWorks::App": "508d500b32261320",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment": "4902f6030931194b",
@@ -770,7 +780,7 @@ types: dict[str, str] = {
     "AWS::PCAConnectorAD::Template": "ed0b568c05022bdf",
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry": "756784fc38981208",
     "AWS::PCAConnectorSCEP::Challenge": "66f2129c2055583e",
-    "AWS::PCAConnectorSCEP::Connector": "9cbd2b6a05e6eb0d",
+    "AWS::PCAConnectorSCEP::Connector": "3985d16f9d690d78",
     "AWS::Pipes::Pipe": "ef04c5b621766de2",
     "AWS::RAM::Permission": "978c532747f94c7b",
     "AWS::RAM::ResourceShare": "b4b5ff31bc5f95b0",
@@ -789,7 +799,7 @@ types: dict[str, str] = {
     "AWS::RDS::GlobalCluster": "a87d030f06c19d47",
     "AWS::RDS::Integration": "b41a67e5adeb023f",
     "AWS::RDS::OptionGroup": "d89f528bd7bdd696",
-    "AWS::RUM::AppMonitor": "7d61f34df1716a89",
+    "AWS::RUM::AppMonitor": "13586103a13794ef",
     "AWS::Rbin::Rule": "7302f3e4816f5e9e",
     "AWS::Redshift::Cluster": "24380b75d618dc41",
     "AWS::Redshift::ClusterParameterGroup": "5eafb174c8375f06",
@@ -899,7 +909,7 @@ types: dict[str, str] = {
     "AWS::SQS::QueuePolicy": "8d0c3b8154e71ff3",
     "AWS::SSM::Association": "e5ce83b562338270",
     "AWS::SSM::Document": "fafd81d675e3af92",
-    "AWS::SSM::MaintenanceWindow": "54b31dcf040d1e3b",
+    "AWS::SSM::MaintenanceWindow": "8bcf8299c61efe9b",
     "AWS::SSM::MaintenanceWindowTarget": "1d59aec599d718b8",
     "AWS::SSM::MaintenanceWindowTask": "dbf020e1bce02a1c",
     "AWS::SSM::Parameter": "88998b8e50aa846a",
@@ -930,9 +940,9 @@ types: dict[str, str] = {
     "AWS::SageMaker::Endpoint": "bcd29d1fafd461ae",
     "AWS::SageMaker::EndpointConfig": "7c3a65bd96c2e9a3",
     "AWS::SageMaker::FeatureGroup": "2fd87c841fd87a48",
-    "AWS::SageMaker::Image": "1f7b8f5745496bd2",
+    "AWS::SageMaker::Image": "564da26f07cd2046",
     "AWS::SageMaker::ImageVersion": "307ec283c9c38549",
-    "AWS::SageMaker::InferenceExperiment": "b19e56ad811b2cbd",
+    "AWS::SageMaker::InferenceExperiment": "a15f7a6adffaf10d",
     "AWS::SageMaker::MlflowTrackingServer": "82716f2317f73364",
     "AWS::SageMaker::Model": "9757bf2bdc6a25ef",
     "AWS::SageMaker::ModelBiasJobDefinition": "1357485edb491230",
@@ -981,9 +991,9 @@ types: dict[str, str] = {
     "AWS::ServiceCatalog::CloudFormationProduct": "662186534ff8e643",
     "AWS::ServiceCatalog::CloudFormationProvisionedProduct": "448a377417beb2e5",
     "AWS::ServiceCatalog::LaunchNotificationConstraint": "b7978856af5cccf2",
-    "AWS::ServiceCatalog::LaunchRoleConstraint": "dfc41af30527c286",
+    "AWS::ServiceCatalog::LaunchRoleConstraint": "645835eeed030de3",
     "AWS::ServiceCatalog::LaunchTemplateConstraint": "e457535596ed60a2",
-    "AWS::ServiceCatalog::Portfolio": "2802283288dedb80",
+    "AWS::ServiceCatalog::Portfolio": "3f12b2c638b77209",
     "AWS::ServiceCatalog::PortfolioPrincipalAssociation": "c1655e6cd9e94bc0",
     "AWS::ServiceCatalog::PortfolioProductAssociation": "39311ae1cb0b583e",
     "AWS::ServiceCatalog::PortfolioShare": "c365f2118140f92b",
